@@ -1,6 +1,6 @@
 /*
 * alarm.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -9,16 +9,21 @@
 #define __ALARM__
 
 struct alarm_t { 
-	double triggert;
+
+  double triggert;
   double startt;
-	double nowt;
-	double elapsed;
+  double nowt;
+  double elapsed;
   int active;
-  alarm_t (double tt = 1.0); 
-  int operator() (double t);
-	double operator() ();
-  void start ();
+
+  alarm_t (double tt = 1.0);
+  int operator() (double nowt);
+  double operator() ();
+  void start (double delta = 0.0);
   void stop ();
+
 };
 
+typedef alarm_t alarmt;
+
 #endif
