@@ -1,12 +1,12 @@
 /*
 * angle.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
 
-#ifndef __angle
-#define __angle
+#ifndef __anglet__
+#define __anglet__
 
 #include <fstream>
 
@@ -45,5 +45,4 @@ struct anglet {
 std::ostream& operator<< (std::ostream& f, anglet& a);
 std::istream& operator>> (std::istream& f, anglet& a);
 
-
 #endif
