@@ -1,12 +1,17 @@
 /*
 * arrow_button.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
 
 #include "arrow_button.h"
 
+arrow_button::arrow_button (int _sz, int _dir) {
+  set_size (_sz);
+  set_dir (_dir);
+}
+
 void arrow_button::set_dir (int _dir) {
   dir = _dir;
   const box<int>& e = extents;
@@ -55,11 +60,11 @@ void arrow_button::set_dir (int _dir) {
 }
 
 void arrow_button::draw () {
-	widget::draw ();
+  widget::draw ();
   glVertexPointer (2, GL_INT, 0, v);
   glDrawArrays (GL_LINE_LOOP, 0, 3);
 }
 
 void arrow_button::toggle () {
-	if (dir == down) dir = right; else if (dir == right) dir = down;
+  if (dir == down) dir = right; else if (dir == right) dir = down;
 }
