@@ -1,6 +1,6 @@
 /*
 * audio.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -17,16 +17,20 @@
 #include <stdlib.h>
 #include <string>
 #include "utils.h"
+#include "RtAudio.h"
 #include "RtError.h"
 #include "log.h"
 #include "console.h"
+#include "oscilloscope.h"
+
 using namespace std;
 
 extern string user_data_dir;
 extern string APP_NAME;
+extern oscilloscope scope;
 
 #if defined __UNIX_JACK__
-	#define SOUND_API RtAudio::UNIX_JACK
+  #define SOUND_API RtAudio::UNIX_JACK
 #elif defined __LINUX_ALSA__
   #define SOUND_API RtAudio::LINUX_ALSA
 #elif defined __MACOSX_CORE__
@@ -38,14 +42,14 @@ extern string APP_NAME;
 audio_out::audio_out () : dac (SOUND_API) {
 
   samples_buffers = 0;
-	available = 0;
-  result = ams = fms = vol = gatr = mix = mixa = bufL = bufR = fdr1 = fdr2 = 0;
+  available = 0;
+  result = ams = fms = vol = beatr = mix = mixa = bufL = bufR = fdr1 = fdr2 = 0;
 
   prefs_name = user_data_dir + "audio_prefs";
   load_prefs ();
 
   probe ();
-	open ();
+  open ();
 
 }
 
@@ -53,8 +57,8 @@ audio_out::~audio_out () {
 
   save_prefs ();
 
-  int num_ptrs = 11;
-  sample_t* ptr [] = {samples_buffers, result, ams, fms, vol, gatr, mix, bufL, bufR, fdr1, fdr2, mixa};
+  static const int num_ptrs = 12;
+  sample_t* ptr [] = {samples_buffers, result, ams, fms, vol, beatr, mix, bufL, bufR, fdr1, fdr2, mixa};
   for (int i = 0; i < num_ptrs; ++i) if (ptr[i]) delete[] ptr[i];
 
   if (available) delete[] available;
@@ -77,17 +81,17 @@ void audio_out::alloc () {
 
   if (available) delete[] available;
   available = new int [num_samples_buffers];
-	memset (available, 0, num_samples_buffers * sizeof (int));
+  memset (available, 0, num_samples_buffers * sizeof (int));
 
   readi = writei = 0;
   readp = writep = samples_buffers;
 
   int num_ptrs = 11;
-  sample_t** ptr [] = {&result, &ams, &fms, &vol, &gatr, &mix, &bufL, &bufR, &fdr1, &fdr2, &mixa};
+  sample_t** ptr [] = {&result, &ams, &fms, &vol, &beatr, &mix, &bufL, &bufR, &fdr1, &fdr2, &mixa};
   for (int i = 0; i < num_ptrs; ++i) {
     if (ptr[i]) delete[] *ptr[i];
     *ptr[i] = new sample_t [samples_per_channel];
-		memset (*ptr[i], 0, samples_channel_size);
+    memset (*ptr[i], 0, samples_channel_size);
   }
 
 }
@@ -100,11 +104,11 @@ int audio_out::open (int id, unsigned int sr, unsigned int spc) {
 
   RtAudio::StreamParameters parameters;
   if (id > -1 && id < num_devices) {
-		parameters.deviceId = id;
+    parameters.deviceId = id;
   } else {
     id = default_device;
     parameters.deviceId = id;
-	}
+  }
 
   current_device = id;
 
@@ -119,11 +123,11 @@ int audio_out::open (int id, unsigned int sr, unsigned int spc) {
 
   try {
     dac.openStream (&parameters, 0, RTAUDIO_FLOAT32, sr, &spc, audio_wanted, 0, &options);
-		set_samples_per_channel (spc);
+    set_samples_per_channel (spc);
     alloc ();
     set_sample_rate (sr);
     dlog << "+++ opened audio stream +++" << endl;
-		return 1;
+    return 1;
   } catch (RtError& e) {
     dlog << "!!! couldnt open audio stream !!!" << endl;
   }
@@ -160,14 +164,14 @@ void audio_out::load_prefs () {
   string ignore;
 
   if (!file) {
-		dlog << "!!! bad audio_prefs file. sorry, have to abort !!!" << endl;
-		exit (1);
-	} else {
-		file >> ignore >> current_device;
-		file >> ignore >> num_channels;
-		int spc; file >> ignore >> spc; set_samples_per_channel (spc);
-		file >> ignore >> sample_rate;
-		file >> ignore >> num_samples_buffers;
+    dlog << "!!! bad audio_prefs file. sorry, have to abort !!!" << endl;
+    exit (1);
+  } else {
+    file >> ignore >> current_device;
+    file >> ignore >> num_channels;
+    int spc; file >> ignore >> spc; set_samples_per_channel (spc);
+    file >> ignore >> sample_rate;
+    file >> ignore >> num_samples_buffers;
   }
 }
 
@@ -185,21 +189,22 @@ void audio_out::save_prefs () {
 }
 
 void audio_out::set_samples_per_channel (int spc) {
-	samples_per_channel = spc;
-	last_sample = samples_per_channel - 1;
+  samples_per_channel = spc;
+  last_sample = samples_per_channel - 1;
+  scope.alloc (spc);
 }
 
 void audio_out::set_sample_rate (int s) {
-	SAMPLE_RATE = sample_rate = s;
-	SAMPLE_DURATION = 1.0f / SAMPLE_RATE;
-	clk.delta_ticks = samples_per_channel;
-	clk.delta_secs = samples_per_channel * SAMPLE_DURATION;
+  SAMPLE_RATE = sample_rate = s;
+  SAMPLE_DURATION = 1.0f / SAMPLE_RATE;
+  clk.delta_ticks = samples_per_channel;
+  clk.delta_secs = samples_per_channel * SAMPLE_DURATION;
 }
 
 int audio_out::audio_wanted (void *ob, void *ib, unsigned int spc, double t, RtAudioStreamStatus status, void *data) {
 
   // stream audio buffer to audio card
-	//
+  //
 
   if (aout.available[aout.readi]) { // samples buffer written by main thread ready for streaming
     memcpy (ob, aout.readp, aout.samples_buffer_size); // copy written buffer into audio card
@@ -224,44 +229,45 @@ void audio_out::probe () {
   if (num_devices == 0) {
     dlog << "!!! no audio devices found !!!" << endl;
 #ifdef __UNIX_JACK__
-		cout << "!!! Please start JACK before running DIN Is Noise !!!" << endl;
-		cout << "!!! DIN Is Noise aborted !!!" << endl;
-		exit (1);
+    cout << "!!! Please start JACK before running DIN Is Noise !!!" << endl;
+    cout << "!!! DIN Is Noise aborted !!!" << endl;
+    exit (1);
 #endif
   } else {
-		last_device = num_devices - 1;
+    last_device = num_devices - 1;
     dlog << "+++ found " << num_devices << " audio devices +++" << endl;
-		infos.resize (num_devices);
+    infos.resize (num_devices);
     default_device = dac.getDefaultOutputDevice ();
-		dlog << "+++ default output device = " << default_device << " +++" << endl;
-		if (current_device == INVALID) current_device = default_device;
-		next_device = current_device;
+    dlog << "+++ default output device = " << default_device << " +++" << endl;
+    if (current_device == INVALID) current_device = default_device;
+    next_device = current_device;
     for (int i = 0; i < num_devices; ++i) {
-			RtAudio::DeviceInfo& info = infos[i];
+      RtAudio::DeviceInfo& info = infos[i];
       info = dac.getDeviceInfo (i);
       names.push_back (info.name);
-			char br = '[';
-			dlog << "name = " << info.name << " input [default?] = " << info.inputChannels << br << info.isDefaultInput << "], output[default?] = " << info.outputChannels << br << info.isDefaultOutput << "] duplex = " << info.duplexChannels << spc << endl;
-			dlog << "sample rates: ";
-			for (int i = 0, j = info.sampleRates.size (); i < j; ++i) {
-				dlog << info.sampleRates[i] << spc;
-			}
-			dlog << endl;
+      char br = '[';
+      dlog << "name = " << info.name << " input channels [default?] = " << info.inputChannels << br << info.isDefaultInput << "], output channels [default?] = " << info.outputChannels << br << info.isDefaultOutput << "] duplex = " << info.duplexChannels << spc << endl;
+      int k = info.sampleRates.size ();
+      dlog << "sample rates [" << k << "]: ";
+      for (int i = 0, j = info.sampleRates.size (); i < j; ++i) {
+        dlog << info.sampleRates[i] << spc;
+      }
+      dlog << endl;
     }
   }
 
 }
 
 int audio_out::goto_next_device (int i) {
-	next_device = current_device + i;
-	wrap (0, next_device, last_device);
-	if (infos[next_device].outputChannels == 0) {
-		cons << RED << names[next_device] << " has no output channels" << eol;
-		return 0;
-	}
-	current_device = next_device;
-	find_sample_rate_id (sample_rate);
-	return 1;
+  next_device = current_device + i;
+  wrap (0, next_device, last_device);
+  if (infos[next_device].outputChannels == 0) {
+    cons << RED << names[next_device] << " has no output channels" << eol;
+    return 0;
+  }
+  current_device = next_device;
+  find_sample_rate_id (sample_rate);
+  return 1;
 }
 
 void audio_out::find_sample_rate_id (unsigned int sr) {
@@ -284,16 +290,16 @@ int audio_out::goto_next_sample_rate_id (int i) {
 }
 
 void audio_out::list () {
-	default_device = dac.getDefaultOutputDevice ();
-	for (int i = 0; i < num_devices; ++i) {
-		RtAudio::DeviceInfo& info = infos[i];
-		cons << GREEN << "name = " << info.name << " input = " << info.inputChannels <<  " output = " << info.outputChannels \
-				 << " duplex = " << info.duplexChannels << eol;
-		cons << CYAN << "  sample rates: ";
-		for (int i = 0, j = info.sampleRates.size (); i < j; ++i) cons << int (info.sampleRates[i]) << spc;
-		cons << eol;
-	}
-	cons << YELLOW << "number of devices = " << num_devices << eol;
-	cons << "final device = " << last_device << ", next device = " << next_device << eol;
-	cons << "default device = " << default_device << ", current device = " << current_device << eol;
+  default_device = dac.getDefaultOutputDevice ();
+  for (int i = 0; i < num_devices; ++i) {
+    RtAudio::DeviceInfo& info = infos[i];
+    cons << GREEN << "name = " << info.name << " input = " << info.inputChannels <<  " output = " << info.outputChannels \
+         << " duplex = " << info.duplexChannels << eol;
+    cons << CYAN << "  sample rates: ";
+    for (int i = 0, j = info.sampleRates.size (); i < j; ++i) cons << int (info.sampleRates[i]) << spc;
+    cons << eol;
+  }
+  cons << YELLOW << "number of devices = " << num_devices << eol;
+  cons << "final device = " << last_device << ", next device = " << next_device << eol;
+  cons << "default device = " << default_device << ", current device = " << current_device << eol;
 }
