@@ -1,6 +1,6 @@
 /*
 * authors_note.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -23,7 +23,7 @@ authors_note::authors_note () {
 
 void authors_note::enter () {
   rollup = cons.rollup ();
-	cons.rollup (0);
+  cons.rollup (0);
   cons ("show-eval-notice");
 }
 
@@ -42,19 +42,20 @@ void authors_note::draw () {
 
   glMatrixMode (GL_PROJECTION);
   glLoadIdentity ();
-  glOrtho (0, view.xmax, 0, view.ymax, -1, 1);
+  glOrtho (0, view.width, 0, view.height, -1, 1);
+
+  buy_now.draw ();
+  buy_later.draw ();
 
   glMatrixMode (GL_MODELVIEW);
   glLoadIdentity ();
 
-  buy_now.draw ();
-  buy_later.draw ();
 
 }
 
 void authors_note::setup () {
 
-	extern int line_height;
+  extern int line_height;
 
   buy_now.set_text ("Click here to Buy a License.");
   buy_now.set_pos (20, 5 * line_height);
