@@ -1,6 +1,6 @@
 /*
 * checkbutton.cc
-* DIN Is Noise is copyright (c) 2006-2024 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -35,7 +35,7 @@ void checkbutton::turn_off (int call) {
   if (colorize_) set_color (off_color);
   if (state != 0) {
     state = 0;
-		if (call && lsnr) lsnr->changed (*this);
+    if (call && lsnr) lsnr->changed (*this);
   }
 }
 
@@ -92,3 +92,7 @@ void rotdir::draw () {
     glVertex2i (pts[2], pts[3]);
   glEnd ();
 }
+
+void justset (checkbutton& cb, int state) {
+  if (state) cb.turn_on (DONT_CALL_LISTENER); else cb.turn_off (DONT_CALL_LISTENER);
+}
