@@ -1,12 +1,12 @@
 /*
 * command.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
 
 #include "globals.h"
-#include "din.h"
+#include "microtonal-keyboard.h"
 #include "command.h"
 #include "console.h"
 #include "math.h"
@@ -20,8 +20,6 @@
 #include "curve_editor.h"
 #include "tokenizer.h"
 #include "tcl_interp.h"
-#include "chrono.h"
-#include "sine_mixer.h"
 #include "scale_info.h"
 #include "keyboard_keyboard.h"
 #include "main.h"
@@ -34,6 +32,7 @@
 #include "recorder.h"
 #include "circler.h"
 #include "noiser.h"
+#include "sine_mixer.h"
 
 #include <string>
 #include <fstream>
@@ -77,9 +76,6 @@ extern load_globals lg;
 
 extern scale_info scaleinfo;
 
-
-extern sine_mixer sinemixer;
-
 extern string LOCATION;
 extern string VERSION_NUMBER;
 
@@ -91,6 +87,12 @@ extern map <string, float> INTERVALS;
 
 extern scale_info all_notes;
 
+extern int DIN_IS_BINAURAL;
+extern int JUSTIFICATION;
+extern float SEPARATION;
+
+extern float BPM_MULT;
+
 template <class T> void load_vector_from_string (const string& s, vector<T>& data) {
   tokenizer tz (s);
   data.clear ();
@@ -104,12 +106,6 @@ template <class T> void load_vector_from_string (const string& s, vector<T>& dat
   }
 }
 
-void cmdlist::add (command* cmd) {
-	dlog << "added command: " << cmd->longname << " aka " << cmd->shortname << endl;
-  cmds.push_back (cmd);
-  ncmds = cmds.size ();
-}
-
 cmdlist::~cmdlist () {
   dlog << "--- destroyed cmdlist ---" << endl;
 }
@@ -166,67 +162,33 @@ int set_var::operator() (tokenizer& tz) {
       result = "";
     } else extract = 1;
 
-		if (varn == "fmd" || varn == "fm_depth") {
-      tz >> d->fm_depth;
-      hz2step (d->fm_depth, d->fm_step);
-      if (din0.modulate_what == din::MODULATE_VOICE) MENU.sp_fm_depth.set_value (d->fm_depth);
-    } else if (varn == "amd" || varn == "am_depth") {
-      tz >> d->am_depth;
-      if (din0.modulate_what == din::MODULATE_VOICE) MENU.sp_am_depth.set_value (d->am_depth);
-    } else if (varn == "drt" || varn == "drone_rise_time") {
-			float mn, mx; tz >> mn >> mx;
-			din0.dinfo.drone_rise_time.set_min (mn);
-			din0.dinfo.drone_rise_time.set_max (mx);
-		} else if (varn == "dft" || varn == "drone_fall_time") {
-			float mn, mx; tz >> mn >> mx;
-			din0.dinfo.drone_fall_time.set_min (mn);
-			din0.dinfo.drone_fall_time.set_max (mx);
-		} else if (varn == "spar" || varn == "show_parameters") {
+    //
+    // variables
+
+    if (varn == "spar" || varn == "show_parameters") {
       int what; tz >> what;
       if (what) uis.ab_parameters.set_dir (arrow_button::right); else uis.ab_parameters.set_dir (arrow_button::down);
       uis.pal.clicked (uis.ab_parameters);
-    } else if (varn == "dat" || varn == "delta_attack_time") {
-			tz >> mondrian0.delta_attack_time;
-    } else if (varn == "ddt" || varn == "delta_decay_time") {
-			tz >> mondrian0.delta_decay_time;
-		} else if (varn == "su" || varn == "sustain") {
+    } else if (varn == "su" || varn == "sustain") {
       float g; tz >> g; _gotog.set (g);
     } else if (varn == "vv" || varn == "voice_volume") {
       tz >> VOICE_VOLUME;
     } else if (varn == "ins" || varn == "instrument") {
       tz >> INSTRUMENT;
-      find_instrument ();
-    } else if (varn == "hz") {
-      curve_editor* crved = uis.crved;
-      if (crved) {
-        float hz; tz >> hz;
-        crved->set_hz (hz);
-				MENU.sp_waveform_hz.set_value (crved->hz);
-      }
-    } else if (varn == "num_periods" || varn == "nperiods") {
-      curve_editor* crved = uis.crved;
-			if (crved) {
-        int p; tz >> p;
-        crved->set_periods (p);
-      }
-    } else if (varn == "nsec") {
-			tz >> curve_samples::nsec;
-		} else if (varn == "num_sine_samples" || varn == "nss") {
-      int nss; tz >> nss;
-      sinemixer.set_samples (nss);
-			sinemixer.render ();
+      set_current_instrument ();
     } else if (varn == "tu" || varn == "tuning") {
-      string name; tz >> name;
+      string name; 
+      tz >> name >> uis.settings_scr.i_current_tuning;
       string fname = name + ".tuning";
       if (lg.load_intervals (fname)) {
         TUNING = name;
         result = name;
-				all_notes.intervals = INTERVALS;
-				din0.tuning_changed ();
+        all_notes.intervals = INTERVALS;
+        mkb.tuning_changed ();
         keybd2.setup_notes ();
         keybd2.setup_midi_notes ();
         keybd2.calc_visual_params ();
-				mondrian0.calc_visual_params ();
+        mondrian0.calc_visual_params ();
         uis.settings_scr.sn_scale_notes.refresh ();
         cons ("list2var [get-intervals]");
       } else {
@@ -241,21 +203,16 @@ int set_var::operator() (tokenizer& tz) {
       extract = set_zoom_pan (window::PAN_RATE, window::PAN_AMOUNT, varn, tz);
     } else if (varn == "fps") {
       extern int FPS; 
-			tz >> FPS; 
-			if (FPS < 1) FPS = 120;
+      tz >> FPS; 
+      if (FPS < 1) FPS = 120;
       extern double TIME_PER_FRAME; TIME_PER_FRAME = 1.0f / FPS;
-			uis.settings_scr.sp_fps.set_value (FPS);
+      uis.settings_scr.sp_fps.set_value (FPS);
     } else if (varn == "ips") {
-			extern int IPS; tz >> IPS; if (IPS <= 0) IPS = 100;
-			extern double TIME_PER_INPUT; TIME_PER_INPUT = 1.0 / IPS;
-			uis.settings_scr.sp_ips.set_value (IPS);
-		} else if (varn == "mixt" || varn == "mixing_time") {
-			tz >> curve_mixer::TIME;
-    } else if (varn == "mixs" || varn == "mixing_samples") {
-			int s; tz >> s; if (s < 1) s = 1;
-			curve_mixer::SAMPLES = s;
-    } else if (varn == "dlt" || varn == "drone_life_time") {
-      tz >> drone::LIFETIME;
+      extern int IPS; tz >> IPS; if (IPS < 1) IPS = 100;
+      extern double TIME_PER_INPUT; TIME_PER_INPUT = 1.0 / IPS;
+      uis.settings_scr.sp_ips.set_value (IPS);
+    } else if (varn == "mixt" || varn == "mixing_time") {
+      tz >> curve_mixer::TIME;
     } else if (varn == "tl" || varn == "trail_length") {
       tz >> TRAILSIZE;
       if (TRAILSIZE < 1) TRAILSIZE = 0;
@@ -263,93 +220,66 @@ int set_var::operator() (tokenizer& tz) {
       int fold; tz >> fold;
       cons.rollup (fold);
     } else if (varn == "midi_in") {
-			tz >> midiin.input_port;
-		} else if (varn == "stepz") {
-			string s; tz >> s;
-			MENU.lf_conn_steps.set_text (s);
-			MENU.stepsl.typing (MENU.lf_conn_steps.fld);
-			MENU.stepsl.changed (MENU.lf_conn_steps.fld);
-		} else if (varn == "fft") {
-      int e; tz >> e; 
-      if (e) {
-        fft0.ab_fold.set_dir (arrow_button::right);
-      } else {
-        fft0.ab_fold.set_dir (arrow_button::down);
-      }
-      fft0.clicked (fft0.ab_fold);
+      tz >> midiin.input_port;
+    } else if (varn == "stepz") {
+      string s; tz >> s;
+      MENU.lf_conn_steps.set_text (s);
+      MENU.stepsl.typing (MENU.lf_conn_steps.fld);
+      MENU.stepsl.changed (MENU.lf_conn_steps.fld);
     } else if (varn == "current_plugin") {
       int c; tz >> c;
-			uis.plugin__browser.set_cur (c);
-    } else if (varn == "bdt" || varn == "ball.decay_time") {
-			float dt; tz >> dt;
-			mondrian0.set_ball_param (ball::SET_DECAY_TIME, dt);
-		} else if (varn == "bat" || varn == "ball.attack_time") {
-			float at; tz >> at;
-			mondrian0.set_ball_param (ball::SET_ATTACK_TIME, at);
-		} else if (varn == "bvm" || varn == "ball.vol_mult")  {
-			float vm; tz >> vm;
-			mondrian0.set_ball_param (ball::SET_VOL_MULT, vm);
-		} else if (varn == "ds" || varn == "mondrian.delta_speed") {
-			tz >> mondrian0.delta_speed;
-		} else if (varn == "drv" || varn == "mondrian.delta_rotate_velocity") {
-			tz >> mondrian0.delta_rotate_velocity;
-		} else if (varn == "recorder.fname") {
-      string fname; tz >> fname;
-      recorder0.set_fname (fname);
-    } else if (varn == "recorder.stop_mins") {
-      int mins; tz >> mins;
-      recorder0.stop_mins = mins;
-      recorder0.stop_rec = 1;
-    } else if (varn == "recorder.stop_secs") {
-      int secs; tz >> secs;
-      recorder0.stop_secs = secs;
-      recorder0.stop_rec = 1;
-    } else if (varn == "recorder.start") {
-      recorder0.start ();
-    } else if (varn == "recorder.stop") {
-      recorder0.stop ();
-    } else if (varn == "recorder.save") {
-      recorder0.start_saving ();
-    } else if (varn == "recorder.clear") {
-      recorder0.clear ();
-    } else if (varn == "location" || varn == "loc") {
-			tz >> LOCATION;
-			set_window_caption ();
-		} else if (varn == "version" || varn == "ver") {
-			tz >> VERSION_NUMBER;
-			set_window_caption ();
-		} else if (varn == "snap_lr") {
-			tz >> din0.dinfo.snap.left >> din0.dinfo.snap.right;
-		} else if (varn == "min_mag" || varn == "mm") {
+      uis.plugin__browser.set_cur (c);
+    } else if (varn == "ds" || varn == "mondrian.delta_speed") {
+      tz >> mondrian0.delta_speed;
+    } else if (varn == "drv" || varn == "mondrian.delta_rotate_velocity") {
+      tz >> mondrian0.delta_rotate_velocity;
+    } else if (varn == "mondrian.texture") {
+      tz >> mondrian::patstr;
+      mondrian::patlen = mondrian::patstr.length ();
+      mondrian0.fillpatbuf ();
+    } else if (varn == "mondrian.texstep") {
+      tz >> mondrian::patstep;
+      mondrian0.fillpatbuf ();
+    } else if (varn == "version" || varn == "ver") {
+      tz >> VERSION_NUMBER;
+      set_window_caption ();
+    } else if (varn == "min_mag" || varn == "mm") {
       tz >> drone::posafxvelt::minmag;
-    } else if (varn == "gab-time" || varn == "gt") {
-      tz >> drone::gabt;
-      MENU.sp_gabt.set_value (drone::gabt);
-    } else if (varn == "gab-time-variance" || varn == "gtv") {
-      string s; tz >> s;
-      MENU.sp_gabt.variance.fld.set_text (s);
-      MENU.sp_gabt.variance.fld.change_lsnr->changed (MENU.sp_gabt.variance.fld);
-    }
-    else if (varn == "wand" || varn == "drone_wand_dist") {
+    } else if (varn == "wand" || varn == "drone_wand_dist") {
       double d; tz >> d;
       drone::wand.set (d);
-    }  
-
-    /*else if (varn == "chuck") {
-      din0.chuck ();
-    }
-    else if (varn == "cs") {
-      tz >> din0.selected_drones[0]->chuck.speed;
-    }*/
-
-		else {
+    } else if (varn == "curve-samples-nsec") {
+      float t; tz >> t;
+      curve_samples::nsec = t;
+    } else if (varn == "din-is-binaural") {
+      tz >> DIN_IS_BINAURAL;
+    } else if (varn == "justification") {
+      tz >> JUSTIFICATION;
+    } else if (varn == "separation") {
+      tz >> SEPARATION;
+    } else if (varn == "bm" || varn == "bpmmult") {
+      tz >> BPM_MULT;
+    } else if (varn == "c" || varn == "cursor") {
+      basic_editor* pb = uis.crved;
+      if (pb) {
+        basic_editor& b = *pb;
+        string x, y; tz >> x >> y;
+        if (x == "."); else b.cursor.ox = atof (x.c_str());
+        if (y == "."); else b.cursor.oy = atof (y.c_str());
+        b.cursor.calcv (pb);
+        warp_mouse (b.cursor.vx, view.ymax - b.cursor.vy);
+        cons.toggle_command_mode ();
+      } else {
+        cons << RED << "set-var cursor can be used on curve editors only!" << eol;
+      }
+    } else {
       if (varn != "") {
-        result = varn + ": not found.";
+        result = varn + ": variable not found.";
         return 0;
-      } else break;
+      } else 
+        break;
     }
-
-	}
+  }
   return 1;
 }
 
@@ -358,24 +288,7 @@ int get_var::operator() (tokenizer& tz) {
   string varn;
   while (1) {
     tz >> varn;
-    if (varn == "fmd" || varn == "fm_depth") {
-      ss << d->fm_depth << spc;
-    } else if (varn == "amd" || varn == "am_depth") {
-      ss << d->am_depth << spc;
-    } else if (varn == "drt" || varn == "drone_rise_time") {
-			ss << din0.dinfo.drone_rise_time.min << spc << din0.dinfo.drone_rise_time.max << spc;
-		} else if (varn == "dft" || varn == "drone_fall_time") {
-			ss << din0.dinfo.drone_fall_time.min << spc << din0.dinfo.drone_fall_time.max << spc;
-		} else if (varn == "is_ed" || varn == "is_curve_editor") {
-			ss << uis.current->ed << spc;
-		} else if (varn == "ed_id" || varn == "curve_editor_id") {
-			sprintf (BUFFER, "%u", (uintptr_t) uis.crved);
-			ss << BUFFER << spc;
-		} else if (varn == "pb" || varn == "pitch_bend") {
-      ss << PITCH_BEND << spc;
-    } else if (varn == "snn" || varn == "show_nearby_notes") {
-      ss << keybd2.show_nearby_notes << spc;
-    } else if (varn == "spar" || varn == "show_parameters") {
+    if (varn == "spar" || varn == "show_parameters") {
       int show_parameters = 0;
       if (uis.ab_parameters.dir == arrow_button::down) show_parameters = 1;
       ss << show_parameters << spc;
@@ -383,19 +296,10 @@ int get_var::operator() (tokenizer& tz) {
       ss << VOICE_VOLUME << spc;
     } else if (varn == "su" || varn == "sustain") {
       ss << _gotog.g << spc;
-    } else if (varn == "num_octaves" || varn == "no") {
-      ss << NUM_OCTAVES << spc;
-    } else if (varn == "hz") {
-      curve_editor* crved = uis.crved;
-      if (crved) {
-        ss << crved->hz << spc;
-      } else ss << -1 << spc;
     } else if (varn == "ins" || varn == "instrument") {
       ss << INSTRUMENTS [CURRENT_INSTRUMENT] << spc;
     } else if (varn == "tu" || varn == "tuning") {
-      ss << TUNING << spc;
-    } else if (varn == "scale") {
-      ss << SCALE << spc;
+      ss << TUNING << spc << uis.settings_scr.i_current_tuning << spc;
     } else if (varn == "sc" || varn == "scroll") {
       sprintf (BUFFER, "rate %d x %d y %d ", d->dinfo.scroll.rate, d->dinfo.scroll.dx, d->dinfo.scroll.dy);
       ss << BUFFER << spc;
@@ -405,137 +309,70 @@ int get_var::operator() (tokenizer& tz) {
       ss << "rate " << window::PAN_RATE << " amount " << window::PAN_AMOUNT << spc;
     } else if (varn == "fps") {
       extern int FPS; ss << FPS << spc;
-		} else if (varn == "gfps") {
-      extern double LAST_FRAME_TIME;
-      ss << 1.0 / LAST_FRAME_TIME << spc;
     } else if (varn == "ips") {
-			extern int IPS; ss << IPS << spc;
-		} else if (varn == "mixt"  || varn == "mixing_time") {
-			ss << curve_mixer::TIME << spc;
-		} else if (varn == "mixs" || varn == "mixing_samples") {
-			ss << int (curve_mixer::TIME * SAMPLE_RATE + 0.5) << spc;
-		} else if (varn == "num_sine_samples" || varn == "nss") {
-      ss << sine_mixer::NUM_SINE_SAMPLES << spc;
-    } else if (varn == "dlt" || varn == "drone_life_time") {
-      ss << drone::LIFETIME << spc;
+      extern int IPS; ss << IPS << spc;
+    } else if (varn == "mixt"  || varn == "mixing_time") {
+      ss << curve_mixer::TIME << spc;
+    } else if (varn == "mixs" || varn == "mixing_samples") {
+      ss << int (curve_mixer::TIME * SAMPLE_RATE + 0.5) << spc;
     } else if (varn == "tl" || varn == "trail_length") {
       ss << TRAILSIZE << spc;
     } else if (varn == "fc" || varn == "fold_console") {
       ss << cons.rollup () << spc;
     } else if (varn == "midi_in") {
-			ss << midiin.input_port << spc;
-		} else if (varn == "stepz") {
-			ss << MENU.lf_conn_steps.fld.text << spc;
-		} else if (varn == "sine_mixer") {
-      ss << !sinemixer.folded () << spc;
-    } else if (varn == "fft") {
-      ss << !fft0.folded () << spc;
-    } else if (varn == "nperiods") {
-      if (uis.crved) ss << uis.crved->nperiods << spc;
+      ss << midiin.input_port << spc;
+    } else if (varn == "stepz") {
+      ss << MENU.lf_conn_steps.fld.text << spc;
+    } else if (varn == "curve-samples-nsec") {
+      ss << curve_samples::nsec << spc;
     } else if (varn == "current_plugin") {
       ss << uis.plugin__browser.cur << spc;
-    } else if (varn == "mondrian.added_ball_type") {
-			ss << mondrian0.added_ball_type << spc;
-		} else if (varn == "mondrian.num_boxes") {
-			ss << mondrian0.num_boxes << spc;
-		} else if (varn == "mondrian.delta_speed") {
+    } else if (varn == "mondrian.delta_speed") {
       ss << mondrian0.delta_speed << spc;
     } else if (varn == "mondrian.delta_rotate_velocity") {
-			ss << mondrian0.delta_rotate_velocity << spc;
-		} else if (varn == "mondrian.cursor") {
-      ss << mondrian0.cursor << spc;
-    } else if (varn == "mondrian.min_voices") {
-      ss << mondrian0.min_voices << spc;
-    } else if (varn == "mondrian.auto_adjust_voices") {
-			ss << mondrian0.auto_adjust_voices << spc;
-		} else if (varn == "mondrian.draw_ball_position") {
-			ss << mondrian0.draw_ball.position << spc;
-		} else if (varn == "mondrian.draw_boxes") {
-			ss << mondrian0.draw__boxes << spc;
-		} else if (varn == "mondrian.fill_boxes") {
-			ss << mondrian0.fill_boxes << spc;
-		} else if (varn == "mondrian.draw_notes") {
-			ss << mondrian0.draw__notes << spc;
-		} else if (varn == "mondrian.label_notes") {
-			ss << mondrian0.label_notes << spc;
-		} else if (varn == "mondrian.delta_attack_time") {
-      ss << mondrian0.delta_attack_time << spc;
-    } else if (varn == "mondrian.delta_decay_time") {
-      ss << mondrian0.delta_decay_time << spc;
-    } else if (varn == "mondrian.half_slit_size") {
-			ss << slit::HALF_SIZE << spc;
-		} else if (varn == "mondrian.auto_delete_rect") {
-      ss << mondrian0.auto_del_rect.active << spc;
-    } else if (varn == "mondrian.auto_delete_time") {
-      ss << mondrian0.auto_del_rect.triggert << spc;
-    } else if (varn == "mondrian.auto_split_rect") {
-      ss << mondrian0.auto_split_rect.active << spc;
-    } else if (varn == "mondrian.auto_split_time") {
-      ss << mondrian0.auto_split_rect.triggert << spc;
-    } else if (varn == "mondrian.auto_split_orient") {
-      ss << mondrian0.auto_split_orient << spc;
-    } else if (varn == "mondrian.auto_split_at") {
-      ss << mondrian0.auto_split_at << spc;
-    } else if (varn == "mondrian.pick_box_split") {
-			ss << mondrian0.split_leaf << spc;
-		} else if (varn == "mondrian.pick_box_delete") {
-			ss << mondrian0.delete_leaf << spc;
-		} else if (varn == "mondrian.min_split_size") {
-      ss << mondrian::min_split_size << spc;
-    } else if (varn == "mondrian.draw_ball_position") {
-			ss << mondrian0.draw_ball.position << spc;
-		} else if (varn == "mondrian.draw_ball_heading") {
-			ss << mondrian0.draw_ball.heading << spc;
-		} else if (varn == "mondrian.draw_ball_trails") {
-			ss << mondrian0.draw_ball.trails << spc;
-		} else if (varn == "mondrian.turn_sync") {
-			ss << MENU.cb_turn_sync.state << spc;
-		} else if (varn == "mondrian.speed_sync") {
-			ss << MENU.cb_speed_sync.state << spc;
-		} else if (varn == "microtonal_keyboard.scale") {
-			ss << din0.scaleinfo.name << spc;
-		} else if (varn == "keyboard_keyboard.scale") {
-			ss << keybd2.scaleinfo.name << spc;
-		} else if (varn == "mondrian.scale") {
-			ss << mondrian0.scaleinfo.name << spc;
-		} else if (varn == "binaural_drones.scale") {
-			ss << binaural_drones0.scaleinfo.name << spc;
-		} else if (varn == "binaural_drones.master_volume") {
-			ss << binaural_drones0.master_volume << spc;
-		} else if (varn == "binaural_drones.justification") {
-      ss << binaural_drones0.just << spc;
-    } else if (varn == "binaural_drones.modulation_amount") {
-			ss << binaural_drones0.modulation_amount << spc;
-		} else if (varn == "recorder.mins") {
-      ss << recorder0.rec_time_add.mins << spc;
-    } else if (varn == "recorder.secs") {
-      ss << recorder0.rec_time_add.secs << spc;
+      ss << mondrian0.delta_rotate_velocity << spc;
+    } else if (varn == "mondrian.texture") {
+      ss << mondrian0.patstr << spc;
+    } else if (varn == "mondrian.texstep") {
+      ss << mondrian0.patstep << spc;
+    } else if (varn == "microtonal_keyboard.scale") {
+      ss << mkb.scaleinfo.name << spc;
+    } else if (varn == "keyboard_keyboard.scale") {
+      ss << keybd2.scaleinfo.name << spc;
+    } else if (varn == "mondrian.scale") {
+      ss << mondrian0.scaleinfo.name << spc;
     } else if (varn == "notation") {
-			ss << NOTATION << spc;
-		} else if (varn == "location") {
-			ss << LOCATION << spc;
-		} else if (varn == "version") {
-			ss << VERSION_NUMBER << spc;
-		} else if (varn == "snap_lr") {
-			ss << din0.dinfo.snap.left << spc << din0.dinfo.snap.right << spc;
-		} else if (varn == "min_mag" || varn == "mm") {
+      ss << NOTATION << spc;
+    } else if (varn == "version") {
+      ss << VERSION_NUMBER << spc;
+    } else if (varn == "min_mag" || varn == "mm") {
       ss << drone::posafxvelt::minmag << spc;
-    } else if (varn == "gab-time" || varn == "gt") {
-      ss << drone::gabt << spc;
-    } else if (varn == "gab-time-variance" || varn == "gtv") {
-      ss << MENU.sp_gabt.variance.fld.text << spc;
     } else if (varn == "wand" || varn == "drone_wand_dist") {
       ss << drone::wand.dist << spc;
+    } else if (varn == "binaural_drones.scale") {
+      ss << binaural_drones0.scaleinfo.name << spc;
+    } else if (varn == "binaural_drones.master_volume") {
+      ss << binaural_drones0.master_volume << spc;
+    } else if (varn == "binaural_drones.justification") {
+      ss << binaural_drones0.just << spc;
+    } else if (varn == "is_curve_editor") {
+      ss << uis.current->ed << spc;
+    } else if (varn == "curve_editor_id") {
+      sprintf (BUFFER, "%u", (uintptr_t) uis.crved);
+      ss << BUFFER << spc;
+    } else if (varn == "din-is-binaural") {
+      ss << DIN_IS_BINAURAL << spc;
+    } else if (varn == "justification") {
+      ss << JUSTIFICATION << spc;
+    } else if (varn == "separation") {
+      ss << SEPARATION << spc;
+    } else if (varn == "bm" || varn == "bpmmult") {
+      ss << BPM_MULT << spc;
     }
-
-    /*else if (varn == "cs") {
-      ss << din0.selected_drones[0]->chuck.scale << spc;
-    }*/
-
-		else {
+    else {
       if (varn != "") {
         result = varn + ": not found.";
-				dlog << result << endl;
+        dlog << result << endl;
         return 0;
       } else break;
     }
@@ -547,27 +384,41 @@ int get_var::operator() (tokenizer& tz) {
 int set_delay::operator() (tokenizer& tz) {
 
   string name;
-  float value;
+  float nbeats;
 
-  delay* d[2] = {left, right};
-  delay** pd = d;
-  int n = -1;
+  delay* d = 0;
 
-  tz >> name >> value;
+  delaylevels& dl = uis.delaylevs;
+  float* f = 0;
 
-  if (name == "a" || name == "all") n = 2;
-  else if (name == "l" || name == "left") n = 1;
-  else if (name == "r" || name == "right") {
-    pd++;
-    n = 1;
-  } else {
+  float bps;
+  tz >> name >> nbeats >> bps;
+
+  string sc ("L ");
+  label_field* lf = 0;
+  if (name == "right" || name == "r") {
+    d = &right_delay; 
+    f = &dl.R.beats;
+    sc = "R ";
+    lf = &uis.settings_scr.r_delay_dur;
+  }
+  else if (name == "left" || name == "l") {
+    d = &left_delay;
+    f = &dl.L.beats;
+    lf = &uis.settings_scr.l_delay_dur;
+  }
+  else {
     result = "bad delay name";
     return 0;
   }
 
-  for (int i = 0; i < n; ++i, pd++) {
-    (*pd)->set (value);
-  }
+  if (nbeats < 0) nbeats = 1.0f;
+  if (bps < 0) bps = 1;
+  d->set (nbeats, bps);
+  *f = nbeats;
+
+  sprintf (BUFFER, "delay in beats @ %.2f BPM", bps * 60);
+  lf->set_label (sc+BUFFER);
 
   return 1;
 
@@ -575,19 +426,18 @@ int set_delay::operator() (tokenizer& tz) {
 
 int get_delay::operator() (tokenizer& tz) {
 
-  delay* d;
+  delay* d = 0;
   string s; tz >> s;
-  if (s == "left" || s == "l") d = left;
-  else if (s == "right" || s == "r") d = right;
+  if (s == "left" || s == "l") d = &left_delay;
+  else if (s == "right" || s == "r") d = &right_delay;
   else {
     result = "bad delay name";
     return 0;
   }
 
-  float t; d->get (t);
-  sprintf (BUFFER, "%0.2f", t);
+  float b, bps; d->get (b, bps);
+  sprintf (BUFFER, "%f %f", b, bps);
   result = BUFFER;
-
   return 1;
 
 }
@@ -602,7 +452,6 @@ int bpm_com::get_bpm_id_from_name (const string& name) {
 }
 
 int ls_bpm::operator() (tokenizer& tz) {
-  static const char spc = spc;
   for (int i = 0;i < NUM; ++i) {
     result = result + str[i] + spc;
   }
@@ -616,7 +465,10 @@ int set_bpm::operator() (tokenizer& tz) {
   int id = get_bpm_id_from_name (name);
   if (id != -1) {
     bv[id]->set_bpm (bpm);
-    MENU.update_bpm (name, bpm);
+    if (id == 0) {
+      MENU.sp_octave_shift_bpm.set_value (bpm);
+      uis.sp_octave_shift_bpm.set_value (bpm);
+    }
   }
   return 1;
 }
@@ -671,30 +523,17 @@ int get_beat::operator() (tokenizer& tz) {
 
 int set_style::operator() (tokenizer& tz) {
   vector<string> names;
-  vector<string> styles;
+  vector<int> styles;
   string s;
   tz >> s; load_vector_from_string (s, names);
   tz >> s; load_vector_from_string (s, styles);
   for (int i = 0, j = names.size (), k = styles.size (), l = k - 1; i < j; ++i) {
     int id = get_bpm_id_from_name (names[i]);
     if (id != -1) {
-      string style;
+      int style = beat2value::LOOP;
       if (i < k) style = styles[i]; else if (l > -1) style = styles[l];
-      xhandler *xmin = 0, *xmax = 0;
-      if (style == "loop") {
-        xmin = &_loopmin;
-        xmax = &_loopmax;
-      } else if (style == "pong") {
-        xmin = &_pongmin;
-        xmax = &_pongmax;
-      } else {
-        result = "bad style: " + style;
-        return 0;
-      }
       beat2value* b = bv[id];
-      b->xmin = xmin;
-      b->xmax = xmax;
-      b->style = style;
+      b->setstyle (style);
     }
   }
   return 1;
@@ -737,15 +576,15 @@ int remove_scale::operator() (tokenizer& tz) {
 
 int load_scale::operator() (tokenizer& tz) {
   string inst, scale; 
-	tz >> inst >> scale;
+  tz >> inst >> scale;
   if (scale != "") {
-		instrument* instr = find_instrument (inst);
-		if (instr) {
-			instr->scaleinfo.load_scale (scale);
-     	SCALE = scale;
-     	result = "scale is " + scale;
-     	return 1;
-		} else return 0;
+    instrument* instr = set_current_instrument (inst);
+    if (instr) {
+      instr->scaleinfo.load_scale (scale);
+      SCALE = scale;
+      result = "scale is " + scale;
+      return 1;
+    } else return 0;
   } else {
     result = scale + ": not found";
     return 0;
@@ -986,7 +825,7 @@ int chord::operator() (tokenizer& tz) {
       stringstream ss1, ss2;
       for (int i = 0, j = ch[0], k = 1; i < j; ++i, ++k) {
         int p = (nn + ch[k]) % 12;
-				ss1 << WESTERN_FLAT [p] << spc;
+        ss1 << WESTERN_FLAT [p] << spc;
         ss2 << WESTERN_SHARP [p] << spc;
       }
       result = ss1.str () + ss2.str ();
@@ -1002,13 +841,13 @@ extern float NEAREST_NOTE_DISTANCE;
 
 int key::operator() (tokenizer& tz) {
 
-	string inst, s; tz >> inst >> s;
+  string inst, s; tz >> inst >> s;
 
-	instrument* instr = find_instrument (inst);
+  instrument* instr = set_current_instrument (inst);
 
   string note ("invalid-note");
   float tonic = get_tonic (instr);
-	NEAREST_NOTE_FREQUENCY = tonic;
+  NEAREST_NOTE_FREQUENCY = tonic;
 
   if (s == "") {
     // no args, just print key
@@ -1021,7 +860,7 @@ int key::operator() (tokenizer& tz) {
     result = BUFFER;
     return 1;
   } else if (s == "note" || s == "n") {
-		find_nearest_note (NEAREST_NOTE, NEAREST_NOTE_FREQUENCY, NEAREST_NOTE_DISTANCE);
+    find_nearest_note (NEAREST_NOTE, NEAREST_NOTE_FREQUENCY, NEAREST_NOTE_DISTANCE);
     result = NEAREST_NOTE;
     return 1;
   } else {
@@ -1048,7 +887,7 @@ int key::operator() (tokenizer& tz) {
 
     freq = freq * pow (2.0f, oct);
 
-		set_tonic (instr, freq);
+    set_tonic (instr, freq);
 
   }
 
@@ -1057,7 +896,7 @@ int key::operator() (tokenizer& tz) {
 }
 
 int notation::operator () (tokenizer& tz) {
-	tz >> NOTATION;
+  tz >> NOTATION;
   return 1;
 }
 
@@ -1094,11 +933,10 @@ int curve_value::operator() (tokenizer& tz) {
     float x, y, xs = (float) atof (sx.c_str()), ys = (float) atof (sy.c_str());
 
     if (what == "v") {
-      int carry_tangents = 1;
       crv->get_vertex (id, x, y);
-      if (sx == ".") crv->set_vertex (id, x, ys, carry_tangents); else
-      if (sy == ".") crv->set_vertex (id, xs, y, carry_tangents); else
-      crv->set_vertex (id, xs, ys, carry_tangents);
+      if (sx == ".") crv->set_vertex (id, x, ys); else
+      if (sy == ".") crv->set_vertex (id, xs, y); else
+      crv->set_vertex (id, xs, ys);
       crv->evaluate ();
       return 1;
     } else if (what == "lt") {
@@ -1264,15 +1102,15 @@ int set_text_color::operator() (tokenizer& tz) {
   return 1;
 }
 
-int paste_gater::operator() (tokenizer& tz) {
-
+int paste_beater::operator() (tokenizer& tz) {
+  int clr; tz >> clr;
   if (curve_editor::copy.num_vertices) {
-    extern din din0;
     float r, g, b;
-    din0.gatr.crv->get_color (r, g, b);
-    *din0.gatr.crv = curve_editor::copy;
-    din0.gatr.crv->set_color (r, g, b);
-    din0.gatr.sol.update ();
+    mkb.beatr.crv->get_color (r, g, b);
+      *mkb.beatr.crv = curve_editor::copy;
+    mkb.beatr.crv->set_color (r, g, b);
+    mkb.beatr.sol.update ();
+    if (clr) curve_editor::copy.clear ();
   }
   return 1;
 }
@@ -1305,12 +1143,12 @@ int get_intervals::operator() (tokenizer& tz) {
 
 #define DONTLOADFROMDISK 0
 int num_octaves::operator() (tokenizer& tz) {
-	int lno = NUM_OCTAVES;
+  int lno = NUM_OCTAVES;
   tz >> NUM_OCTAVES;
   if (NUM_OCTAVES < 1) NUM_OCTAVES = 1;
   d.setup_ranges (lno, DONTLOADFROMDISK);
-	if (NUM_OCTAVES < lno) d.update_drone_ranges ();
-	d.refresh_all_drones ();
+  if (NUM_OCTAVES < lno) d.update_drone_ranges ();
+  d.refresh_all_drones ();
   return 1;
 }
 
@@ -1336,29 +1174,29 @@ int set_audio::operator() (tokenizer& tz) {
   if (got != 0) {
     aout.close ();
     int opened = aout.open (cd, sr, spc);
-		if (opened) {
-			//--cons;
-			switch (got) {
-				case 1:
-				case 2:
-					din0.sample_rate_changed ();
-					keybd2.setup_notes(0);
-					binaural_drones0.vol_fader.set_duration (MENU.lf_vol_fade_time.fld);
-					uis.settings_scr.sample_rate_changed ();
-					break;
-				case 3:
-					din0.samples_per_channel_changed ();
-					update_triggered_notes (keybd2.triggered_notes);
-					update_triggered_notes (mondrian0.triggered_notes);
-					break;
-			}
-			//++cons;
-			aout.start ();
-    	return 1;
-		} 
+    if (opened) {
+      //--cons;
+      switch (got) {
+        case 1:
+        case 2:
+          mkb.sample_rate_changed ();
+          keybd2.setup_notes(0);
+          binaural_drones0.vol_fader.set_duration (MENU.lf_vol_fade_time.fld);
+          uis.settings_scr.sample_rate_changed ();
+          break;
+        case 3:
+          mkb.samples_per_channel_changed ();
+          update_triggered_notes (keybd2.triggered_notes);
+          update_triggered_notes (mondrian0.triggered_notes);
+          break;
+      }
+      //++cons;
+      aout.start ();
+      return 1;
+    } 
   } else {
-		aout.list ();
-	}
+    aout.list ();
+  }
 
   return 0;
 
@@ -1385,17 +1223,17 @@ int scale_curve::operator() (tokenizer& tz) {
 #ifdef __SVG__
 
 int write_svg::operator() (tokenizer& tz) {
-	float h, t, left, top;
-	string fn;
-	if (uis.crved) {
-		tz >> h >> t >> fn >> left >> top;
-		uis.crved->write_svg (h, t, fn, left, top);
-	}
-	return 1;
+  float h, t, left, top;
+  string fn;
+  if (uis.crved) {
+    tz >> h >> t >> fn >> left >> top;
+    uis.crved->write_svg (h, t, fn, left, top);
+  }
+  return 1;
 }
 
 int write_trail::operator() (tokenizer& tz) {
-  din0.write_trail ();
+  mkb.write_trail ();
   return 1;
 }
 
@@ -1404,121 +1242,121 @@ int write_trail::operator() (tokenizer& tz) {
 #ifdef __HPGL__
 
 int write_hpgl::operator() (tokenizer& tz) {
-	if (uis.crved) {
-		float scale, penmag;
-		tz >> scale >> penmag;
-		if (scale <= 0 || penmag <= 0) {
-			cons << console::red << "write-hpgl <scale> <pen-switch-mag>" << eol;
-			return 1;
-		}
-		uis.crved->write_hpgl (scale, penmag);
-	}
-	return 1;
+  if (uis.crved) {
+    float scale, penmag;
+    tz >> scale >> penmag;
+    if (scale <= 0 || penmag <= 0) {
+      cons << console::red << "write-hpgl <scale> <pen-switch-mag>" << eol;
+      return 1;
+    }
+    uis.crved->write_hpgl (scale, penmag);
+  }
+  return 1;
 }
 
 #endif
 
 int cmd_binaural_drone::operator() (tokenizer& tz) {
-	string cmd; tz >> cmd;
-	if (cmd == "c" || cmd == "create") {
-		float l_hz, r_hz, vol, sep; 
-		int just;
-		tz >> l_hz >> r_hz >> vol >> just >> sep;
-		int id = binaural_drones0.add (l_hz, r_hz, vol, just, sep);
-		sprintf (BUFFER, "%d", id);
-		result = BUFFER;
-	} else if (cmd == "e" || cmd == "edit") {
-		int which; tz >> which;
-		string what; tz >> what;
-		float value; tz >> value;
-		int num_binaural_drones = binaural_drones0.binaural_drones.size ();
-		if (which > -1 && which < num_binaural_drones) {
-			binaural_drone* bw = binaural_drones0.binaural_drones [which];
-			if (what == "v" || what == "vol") {
-				bw->set_vol (value);
-				binaural_drones0.vol_fader.start ("Volume change");
-			} else if (what == "l" || what == "left") {
-				bw->set_hz (binaural_drone::LEFT, value);
-				binaural_drones0.pitch_fader.start ("Set L Hz");
-			} else if (what == "r" || what == "right") {
-				bw->set_hz (binaural_drone::RIGHT, value);
-				binaural_drones0.pitch_fader.start ("Set R Hz");
-			} else if (what == "b" || what == "both") {
-				float value2; tz >> value2;
-				bw->set_hz (binaural_drone::LEFT, value);
-				bw->set_hz (binaural_drone::RIGHT, value2);
-				binaural_drones0.pitch_fader.start ("Set L & R Hz");
-			} else if (what == "s" || what == "separation") {
-				bw->set_sep (value);
-				binaural_drones0.pitch_fader.start ("Separation set");
-			} else if (what == "m" || what == "modulate") {
-				bw->set_hz (binaural_drone::LEFT, bw->l_hz * value);
-				bw->set_hz (binaural_drone::RIGHT, bw->r_hz * value);
-				binaural_drones0.pitch_fader.start ("Modulation");
-			}
-		} else cons << "bad binaural drone id" << eol;
-	} else if (cmd == "d" || cmd == "delete") {
-		int which; tz >> which;
-		binaural_drones0.remove (which);
-	} else if (cmd == "s" || cmd == "sync") {
-		int n; tz >> n;
-		string list; tz >> list;
-		binaural_drones0.sync (n, list);
-	} else if (cmd == "n" || cmd == "number") {
-		stringstream ss; ss << (int)binaural_drones0.binaural_drones.size ();
-		result = ss.str ();
-	} else if (cmd == "g" || cmd == "get") {
-		string what; tz >> what; int w;
-		if (what == "left") w = binaural_drone::LEFT;
-		else if (what == "right") w = binaural_drone::RIGHT;
-		else if (what == "separation") w = binaural_drone::SEPARATION;
-		else if (what == "volume") w = binaural_drone::VOLUME;
-		else if (what == "selected_volumes") {
-			result = binaural_drones0.get_sel_vol ();
-			return 1;
-		} else if (what == "selected") {
-			result = MENU.il_binaural_drones.get_selected ();
-			return 1;
-		} else {
-			cons << RED << "syntax error: please type help binaural-drone for more information" << eol;
-			return 0;
-		}
-		stringstream ss;
-		for (int i = 0; i < binaural_drones0.num_binaural_drones; ++i) {
-			binaural_drone* bdi = binaural_drones0.binaural_drones[i];
-			float whata [] = {bdi->l_hz, bdi->r_hz, bdi->sep, bdi->vol * 100.0f};
-			ss << whata[w] << spc;
-		}
-		result = ss.str ();
-	} else if (cmd == "update-list" || cmd == "ul" ) {
-		MENU.update_binaurals_list ();
-	} else if (cmd	== "update-selection" || cmd == "us" ) {
-		MENU.bdl.selected (MENU.il_binaural_drones, MENU.il_binaural_drones.cur);
-	}	else if (cmd == "l" || cmd == "list") {
-		binaural_drones0.list ();
-	} 
-	return 1;
+  string cmd; tz >> cmd;
+  if (cmd == "c" || cmd == "create") {
+    float l_hz, r_hz, vol, sep; 
+    int just;
+    tz >> l_hz >> r_hz >> vol >> just >> sep;
+    int id = binaural_drones0.add (l_hz, r_hz, vol, just, sep);
+    sprintf (BUFFER, "%d", id);
+    result = BUFFER;
+  } else if (cmd == "e" || cmd == "edit") {
+    int which; tz >> which;
+    string what; tz >> what;
+    float value; tz >> value;
+    int num_binaural_drones = binaural_drones0.binaural_drones.size ();
+    if (which > -1 && which < num_binaural_drones) {
+      binaural_drone* bw = binaural_drones0.binaural_drones [which];
+      if (what == "v" || what == "vol") {
+        bw->set_vol (value);
+        binaural_drones0.vol_fader.start ("Volume change");
+      } else if (what == "l" || what == "left") {
+        bw->set_hz (binaural_drone::LEFT, value);
+        binaural_drones0.pitch_fader.start ("Set L Hz");
+      } else if (what == "r" || what == "right") {
+        bw->set_hz (binaural_drone::RIGHT, value);
+        binaural_drones0.pitch_fader.start ("Set R Hz");
+      } else if (what == "b" || what == "both") {
+        float value2; tz >> value2;
+        bw->set_hz (binaural_drone::LEFT, value);
+        bw->set_hz (binaural_drone::RIGHT, value2);
+        binaural_drones0.pitch_fader.start ("Set L & R Hz");
+      } else if (what == "s" || what == "separation") {
+        bw->set_sep (value);
+        binaural_drones0.pitch_fader.start ("Separation set");
+      } else if (what == "m" || what == "modulate") {
+        bw->set_hz (binaural_drone::LEFT, bw->l_hz * value);
+        bw->set_hz (binaural_drone::RIGHT, bw->r_hz * value);
+        binaural_drones0.pitch_fader.start ("Modulation");
+      }
+    } else cons << "bad binaural drone id" << eol;
+  } else if (cmd == "d" || cmd == "delete") {
+    int which; tz >> which;
+    binaural_drones0.remove (which);
+  } else if (cmd == "s" || cmd == "sync") {
+    int n; tz >> n;
+    string list; tz >> list;
+    binaural_drones0.sync (n, list);
+  } else if (cmd == "n" || cmd == "number") {
+    stringstream ss; ss << (int)binaural_drones0.binaural_drones.size ();
+    result = ss.str ();
+  } else if (cmd == "g" || cmd == "get") {
+    string what; tz >> what; int w;
+    if (what == "left") w = binaural_drone::LEFT;
+    else if (what == "right") w = binaural_drone::RIGHT;
+    else if (what == "separation") w = binaural_drone::SEPARATION;
+    else if (what == "volume") w = binaural_drone::VOLUME;
+    else if (what == "selected_volumes") {
+      result = binaural_drones0.get_sel_vol ();
+      return 1;
+    } else if (what == "selected") {
+      result = MENU.il_binaural_drones.get_selected ();
+      return 1;
+    } else {
+      cons << RED << "syntax error: please type help binaural-drone for more information" << eol;
+      return 0;
+    }
+    stringstream ss;
+    for (int i = 0; i < binaural_drones0.num_binaural_drones; ++i) {
+      binaural_drone* bdi = binaural_drones0.binaural_drones[i];
+      float whata [] = {bdi->l_hz, bdi->r_hz, bdi->sep, bdi->vol * 100.0f};
+      ss << whata[w] << spc;
+    }
+    result = ss.str ();
+  } else if (cmd == "update-list" || cmd == "ul" ) {
+    MENU.update_binaurals_list ();
+  } else if (cmd  == "update-selection" || cmd == "us" ) {
+    MENU.bdl.selected (MENU.il_binaural_drones, MENU.il_binaural_drones.cur);
+  } else if (cmd == "l" || cmd == "list") {
+    binaural_drones0.list ();
+  } 
+  return 1;
 }
 
 int set_sine_mixer::operator() (tokenizer& tz) {
-	int harmonic;
-	float value;
-	tz >> harmonic >> value;
-	sinemixer.harms.set_only (harmonic, value);
-	return 1;
+  int harmonic;
+  float value;
+  tz >> harmonic >> value;
+  sinemixer.harms.set_only (harmonic, value);
+  return 1;
 }
 
 int change_sine_mixer::operator() (tokenizer& tz) {
-	int harmonic;
-	float amount;
-	tz >> harmonic >> amount;
-	int res = sinemixer.harms.change (harmonic, amount);
-	sprintf (BUFFER, "%d", res);
-	result = BUFFER;
-	return 1;
+  int harmonic;
+  float amount;
+  tz >> harmonic >> amount;
+  int res = sinemixer.harms.change (harmonic, amount);
+  sprintf (BUFFER, "%d", res);
+  result = BUFFER;
+  return 1;
 }
 
 int update_sine_mixer::operator() (tokenizer& tz) {
-	sinemixer.harms.update ();
-	return 1;
+  sinemixer.harms.update ();
+  return 1;
 }
