@@ -1,11 +1,15 @@
 /*
 * console.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
 
 
+#include <algorithm>
+#include <string>
+using namespace std;
+
 #include "console.h"
 #include "font.h"
 #include "input.h"
@@ -13,22 +17,13 @@
 #include "tcl_interp.h"
 #include "tokenizer.h"
 #include "globals.h"
-#include "tcl_interp.h"
 #include "ui_list.h"
 #include "log.h"
-#include <algorithm>
-#include <string>
-using namespace std;
 
 extern cmdlist cmdlst;
 extern char BUFFER [];
 extern int line_height;
 
-void console::calc_startl_iterator () {
-  it_startl = lines.begin ();
-  for (int i = 0; i < startl; ++i, ++it_startl);
-}
-
 void console::add_line (const mesg& ln) {
   lines.push_back (ln);
   ++nlines;
@@ -76,8 +71,7 @@ void console::home () {
 console::console () : b_roll (10, arrow_button::up) {
   maxlines = 512;
   command_mode = 0;
-  last_rollup_ = -1;
-	rollup_ = 0;
+  rollup_ = 0;
   curs_loc = 0;
   curs_locx = 0;
   hid = -1;
@@ -128,11 +122,11 @@ console& console::operator<< (double d) {
 
 console& console::operator<< (char c) {
   if (c == '\n') {
-		//if (suppress == 0) {
-			cur_line.clr = clr;
-			add_line (cur_line);
-		//}
-		cur_line = mesg ();
+    //if (suppress == 0) {
+      cur_line.clr = clr;
+      add_line (cur_line);
+    //}
+    cur_line = mesg ();
   } else cur_line.text += c;
   return *this;
 }
@@ -145,13 +139,6 @@ void console::del () {
   }
 }
 
-void console::calc_visual_params () {
-  char_width = fnt.charwidth.max;
-  lines_per_screen = (win.top - win.bottom) / line_height - GUTTER;
-  startx = win.left + 15;
-  starty = win.top - line_height;
-  rollup (rollup());
-}
 
 void console::draw () {
 
@@ -168,17 +155,17 @@ void console::draw () {
   }
 
   // draw command line
-	glColor3f (cmd_line.clr.r, cmd_line.clr.g, cmd_line.clr.b);
+  glColor3f (cmd_line.clr.r, cmd_line.clr.g, cmd_line.clr.b);
   draw_string (cmd_line.text, cx, cy);
 
   // draw cursor
   if (command_mode) {
     glColor3f (1, 0, 0);
     int px = cx + curs_locx, py = cy - 2;
-    static int pts[4]={0};
-    pts[0]=px;pts[1]=py;pts[2]=px+char_width;pts[3]=py;
-    glVertexPointer (2, GL_INT, 0, pts);
-    glDrawArrays (GL_LINES, 0, 2);
+    glBegin (GL_LINES);
+      glVertex2i (px, py);
+      glVertex2i (px+char_width, py);
+    glEnd ();
   }
 
   // draw rollup arrow
@@ -190,7 +177,7 @@ void console::draw () {
 
 void console::clear () {
   lines.clear ();
-	clear_cmd_line ();
+  clear_cmd_line ();
   nlines = 0;
   startl = 0;
   calc_startl_iterator ();
@@ -202,7 +189,15 @@ void console::set_window (const box<int>& w) {
   calc_visual_params ();
 }
 
-char get_typed_char ();
+void console::calc_visual_params () {
+  char_width = fnt.charwidth.max;
+  lines_per_screen = (win.top - win.bottom) / line_height - GUTTER;
+  startx = win.left + 25;
+  starty = win.top - line_height;
+  rollup (rollup());
+}
+
+extern char get_typed_char ();
 
 int console::handle_input () {
 
@@ -215,11 +210,16 @@ int console::handle_input () {
   if (keypressed (SDLK_TAB) && !ALT) {
     toggle_command_mode ();
     return 1;
-  } else if (command_mode) {
+  } 
+
+  else 
+
+  if (command_mode) {
+
     if (keypressed (SDLK_ESCAPE)) { 
-			toggle_command_mode (); 
-			return 1;
-		}
+      toggle_command_mode (); 
+      return 1;
+    }
 
     ret = 1;
     char c = get_typed_char ();
@@ -238,7 +238,7 @@ int console::handle_input () {
       hid = history.size () - 1;
 
       operator() (cmd_line.text);
-			clear_cmd_line ();
+      clear_cmd_line ();
 
     } else if (keypressedd (SDLK_LEFT)) {
 
@@ -257,11 +257,11 @@ int console::handle_input () {
 
     } else if (hid > -1) {
 
-      if (keypressedd (SDLK_UP)) {
-				set_cmd_line (history[hid--]);
+      if (keypressedd (SDLK_F11)) {
+        set_cmd_line (history[hid--]);
         if (hid < 0) hid = history.size () - 1;
-      } else if (keypressedd (SDLK_DOWN)) {
-				set_cmd_line (history[hid++]);
+      } else if (keypressedd (SDLK_F12)) {
+        set_cmd_line (history[hid++]);
         if (hid >= (int) history.size()) hid = 0;
       }
 
@@ -270,13 +270,14 @@ int console::handle_input () {
     return 1;
 
   } else 
+
   if (keypressed (SDLK_HOME)) home (); else
   if (keypressed (SDLK_END)) end(); else
   if (keypressedd (SDLK_PAGEUP, pg0, pg1)) pgup(); else
   if (keypressedd (SDLK_PAGEDOWN, pg0, pg1)) pgdn(); else
-  if (keypressedd (SDLK_BACKSPACE)) clear(); else
-  if (keypressedd (SDLK_UP, sc0, sc1)) up(1); else
-  if (keypressedd (SDLK_DOWN, sc0, sc1)) down(1);
+  if (keypressed (SDLK_BACKSPACE)) clear(); else
+  if (keypressedd (SDLK_F11, sc0, sc1)) up(1); else
+  if (keypressedd (SDLK_F12, sc0, sc1)) down(1);
 
   return ret;
 
@@ -285,9 +286,9 @@ int console::handle_input () {
 void console::rollup (int r) {
   rollup_ = r;
   if (rollup_ == 1) 
-		b_roll.set_dir (arrow_button::down); 
-	else 
-		b_roll.set_dir (arrow_button::up);
+    b_roll.set_dir (arrow_button::down); 
+  else 
+    b_roll.set_dir (arrow_button::up);
   last ();
 }
 
@@ -298,14 +299,14 @@ console& console::operator() (const string& cmd) {
 
 void console::set_cmd_line (const string& s, const color& c) {
   cmd_line.text = s;
-	cmd_line.clr = c;
+  cmd_line.clr = c;
   curs_loc = cmd_line.text.length ();
   curs_locx = get_char_width (cmd_line.text);
 }
 
 void console::clear_cmd_line () {
-	cmd_line = mesg ();
-	curs_loc = curs_locx = 0;
+  cmd_line = mesg ();
+  curs_loc = curs_locx = 0;
 }
 
 void console::toggle_command_mode () {
@@ -318,9 +319,14 @@ void console::toggle_command_mode () {
 
 void console::clicked (button& b) {
   rollup (!rollup());
-	if (command_mode) widget::focus = this;
+  if (command_mode) widget::focus = this;
 }
 
 console::~console() {
   dlog << "--- destroyed console ---" << endl;
 }
+
+void console::calc_startl_iterator () {
+  it_startl = lines.begin ();
+  for (int i = 0; i < startl; ++i, ++it_startl);
+}
