@@ -1,12 +1,12 @@
 /*
 * crvpt.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
 
-#ifndef __crvpt
-#define __crvpt
+#ifndef __crvpt__
+#define __crvpt__
 
 struct crvpt { // curve point
 
@@ -30,6 +30,3 @@ struct crvpt { // curve point
 };
 
 #endif
-
-
-
