@@ -1,6 +1,6 @@
 /*
 * curve_display.cc
-* DIN Is Noise is copyright (c) 2006-2024 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -17,7 +17,7 @@ extern viewport view;
 
 void curve_display::add_gutter () {
   static const float GUTTER = 0.01f;
-  bbox.resize (GUTTER, GUTTER);
+  bbox.inflate (GUTTER, GUTTER);
 }
 
 void curve_display::unit_bbox () {
@@ -62,7 +62,7 @@ void curve_display::draw () {
 }
 
 void curve_display::draw_curve () {
-	if (!crv) return;
+  if (!crv) return;
   int n = 0, r = 0;
   vector<curve>& curv = crv->curv;
   for (int i = 0, j = curv.size(); i < j; ++i) n += curv[i].vpts.size ();
