@@ -1,6 +1,6 @@
 /*
 * curve_library.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -26,7 +26,7 @@ void curve_library::load (const string& fname) {
   if (inf) {
     string ignore;
     int ncurves; inf >> ignore >> ncurves;
-		curves.resize (ncurves);
+    curves.resize (ncurves);
     for (int i = 0; i < ncurves; ++i) {
       multi_curve& m = curves[i];
       m.load (inf);
@@ -86,7 +86,7 @@ const multi_curve& curve_library::prev () {
 
 const multi_curve& curve_library::next () {
   int ncurves = curves.size ();
-  if (++cur >= ncurves) cur = 0;
+  if (++cur < ncurves) ; else cur = 0;
   if (has_sustain) _gotog.set (sustains[cur]);
   cons << "loaded " << curves[cur].name << " [" << cur + 1 << '/' << ncurves << "]" << eol;
   return curves[cur];
