@@ -1,6 +1,6 @@
 /*
 * delay.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -14,14 +14,16 @@
 
 struct delay { // 1 channel delay
 
-  int nsamples;
+  float beats, bps;
+  float msecs;
 
+  int nsamples;
+  int maxsamples; 
   float* samples;
-  float* fbk;
-  float* vol;
   int id;
 
-  float msecs; // delay time
+  float* fbk;
+  float* vol;
 
   // feedback and volume are beziers solved into fbk and vol
   std::string fbk_fname, vol_fname;
@@ -29,19 +31,21 @@ struct delay { // 1 channel delay
   delay_listener fbk_lis, vol_lis;
   solver fbk_sol, vol_sol;
 
-  delay (float t, const std::string& fn, const std::string& vn);
+  delay (const std::string& fn, const std::string& vn);
   ~delay ();
+
   void zero ();
-  void prep_buffer ();
+
+  void prep ();
+
+  void set (float nbeats, float bps);
+  void set (float nbeats);
+  void get (float& nbeats, float& bps);
+
   void operator() (float* out, int nz, float fdr);
-  void set (float t);
-  void get (float& t);
-	void setup ();
 
 };
 
 extern delay left_delay, right_delay;
+
 #endif
-
-
-
