@@ -1,16 +1,17 @@
 /*
 * dingl.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
 
 #ifndef __dingl
+
 #define __dingl
 
 #include <SDL/SDL_opengl.h>
 
+void linerect (float l, float b, float r, float t);
+void linerect (int l, int b, int r, int t);
+
 #endif
-
-
-
