@@ -1,6 +1,6 @@
 /*
 * fft.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -32,13 +32,14 @@ void fft::setup () {
   widget* ctrls [] = {&ab_fold, &lev, &l_title};
   widget_load ("d_fft", ctrls, 3);
 
-  ab_fold.set_dir (arrow_button::down);
+  ab_fold.set_dir (arrow_button::right);
   ab_fold.set_listener (this);
 
   l_title.set_text ("FFT");
   l_title.add_child (&ab_fold);
   l_title.add_child (&lev);
-	l_title.set_moveable (1);
+  l_title.set_moveable (1);
+  lev.hide ();
 
 }
 
