@@ -1,6 +1,6 @@
 /*
 * field.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -11,8 +11,6 @@
 #include "input.h"
 #include "utils.h"
 #include "tcl_interp.h"
-#include "log.h"
-#include "console.h"
 
 #include <string>
 #include <sstream>
@@ -33,16 +31,17 @@ int field::handle_input () {
   // locate mouse in field
   if (lmb) {
     if (lmb_clicked == 0) {
-			lmb_clicked = 1;
+      lmb_clicked = 1;
       if (hittest (mousex, mouseyy)) {
-				calc_cursor ();
-				edited |= 0;
+        calc_cursor ();
+        edited |= 0;
         widget::focus = this;
+        if (SHIFT) set_text ("");
       } else {
         if (widget::focus == this) {
-					defocus (this);
+          defocus (this);
           lmb_clicked = 0;
-					return 1;
+          return 1;
         }
       }
     }
@@ -59,9 +58,9 @@ int field::handle_input () {
       edited = 1;
 
       if (mode == pushback) 
-				text.push_back (c); 
-			else 
-				text.insert (text.begin() + cursor, c);
+        text.push_back (c); 
+      else 
+        text.insert (text.begin() + cursor, c);
 
       ++len;
       ++last;
@@ -69,27 +68,27 @@ int field::handle_input () {
 
       calc_cursor ();
 
-			if (typing_lsnr) typing_lsnr->typing (*this);
+      if (typing_lsnr) typing_lsnr->typing (*this);
 
     }
 
-		if (keypressed (SDLK_ESCAPE)) { // abort editing
-			focus = 0;
-			defocus (this);
-			return 1;
-		} else
+    if (keypressed (SDLK_ESCAPE)) { // abort editing
+      focus = 0;
+      defocus (this);
+      return 1;
+    } else
     if (keypressed (SDLK_RETURN)) { // finished editing
-			focus = 0;
+      focus = 0;
       call_listener ();
-			defocus(this);
+      defocus(this);
       return 1;
     }
     else if (keypressedd (SDLK_LEFT)) { // move cursor left
-			mode = insert;
+      mode = insert;
       if (--cursor < 0) cursor = 0;
       calc_cursor ();
     } else if (keypressedd (SDLK_RIGHT)) { // move cursor right
-			mode = insert;
+      mode = insert;
       if (++cursor >= len) {
         cursor = len;
         mode = pushback;
@@ -100,14 +99,14 @@ int field::handle_input () {
         --cursor;
         --len;
         if (--last < 0) {
-	  			last = 0;
-					len = 0;
-	  			mode = pushback;
-				}
-				string::iterator e = text.begin () + cursor;
-				if (e != text.end()) text.erase (e);
-				calc_cursor ();
-				if (typing_lsnr) typing_lsnr->typing (*this);
+          last = 0;
+          len = 0;
+          mode = pushback;
+        }
+        string::iterator e = text.begin () + cursor;
+        if (e != text.end()) text.erase (e);
+        calc_cursor ();
+        if (typing_lsnr) typing_lsnr->typing (*this);
         edited = 1;
       }
     }
@@ -117,17 +116,17 @@ int field::handle_input () {
 }
 
 void field::set_text (const string& txt, int _edited) {
-	edited = _edited;
+  edited = _edited;
   text = txt;
   len = text.length ();
-	if (len == 0) {
-		last = 0;
-		cursor = 0;
-	} else {
-  	last = len - 1;
-		cursor = len;
-	}
-	mode = pushback;
+  if (len == 0) {
+    last = 0;
+    cursor = 0;
+  } else {
+    last = len - 1;
+    cursor = len;
+  }
+  mode = pushback;
   calc_cursor ();
 }
 
@@ -143,7 +142,7 @@ void field::set_text (float f, int _edited) {
 
 void field::calc_cursor () {
   string cstr (text.substr (0, cursor));
-  offset = get_char_width (cstr) - 2;
+  offset = get_char_width (cstr);
   update ();
 }
 
@@ -153,12 +152,17 @@ void field::update () {
 }
 
 void field::draw_cursor (int x, int y) {
-  static int pts [4] = {0};
   int cx = x + offset;
+  glBegin (GL_LINES);
+    glVertex2i (cx, y);
+    glVertex2i (cx, y + fnt.charheight.max);
+  glEnd ();
+
+  /*static int pts [4] = {0};
   pts[0]=cx;pts[1]=y;
   pts[2]=cx;pts[3]=y+fnt.charheight.max;
   glVertexPointer (2, GL_INT, 0, pts);
-  glDrawArrays (GL_LINES, 0, 2);
+  glDrawArrays (GL_LINES, 0, 2);*/
 }
 
 void field::draw () {
@@ -173,26 +177,22 @@ void field::init () {
   lmb_clicked = 0;
   focus = 0;
   edited = 0;
-	change_lsnr = 0;
-	typing_lsnr = 0;
-	type = "";
-	expr = 1;
-	fmt = dec3;
+  change_lsnr = 0;
+  typing_lsnr = 0;
+  type = "";
+  expr = 1;
+  fmt = dec3;
 }
 
 field::field () {
-	set_text ("");
-	init ();
+  set_text ("");
+  init ();
 }
 
 field::field (int x, int y, const string& txt) {
   set_text (txt);
   set_pos (x, y);
-	init ();
-}
-
-field::operator int() const {
-  return (atoi (text.c_str()));
+  init ();
 }
 
 field::operator float() const {
@@ -200,11 +200,15 @@ field::operator float() const {
 }
 
 field::operator double() const {
-	return atof (text.c_str());
+  return atof (text.c_str());
+}
+
+field::operator int() const {
+  return (atoi (text.c_str()));
 }
 
 field::operator short() const {
-	return ((short) atoi(text.c_str()));
+  return ((short) atoi(text.c_str()));
 }
 
 int field::hittest (int x, int y) {
@@ -224,7 +228,7 @@ int field::hittest (int x, int y) {
     }
 
     // locate cursor in text
-		//
+    //
     int l = e.left + fnt.charwidth.avg, r;
     if (x <= l) {
       cursor = 0;
@@ -233,20 +237,20 @@ int field::hittest (int x, int y) {
     }
 
     cursor = 0;
-		int r0 = l;
+    int r0 = l;
     for (int i = 0; i < n; ++i) {
       r = r0 + get_char_width (text.substr (0, i + 1)); 
       if (inrange (l, x, r)) { // found!
-				int rn = r - fnt.spacing.ch;
+        int rn = r - fnt.spacing.ch;
         int xl = x - l, xr = rn - x;
-        if (xl <= xr) cursor = i; else cursor = i + 1;
+        if (xl < xr) cursor = i; else cursor = i + 1;
         if (cursor > last) {
-					cursor = len;
-					mode = pushback; 
-				} else mode = insert;
+          cursor = len;
+          mode = pushback; 
+        } else mode = insert;
         return focus;
       }
-			l = r;
+      l = r;
     }
     cursor = len;
     mode = pushback;
@@ -259,17 +263,17 @@ int field::hittest (int x, int y) {
 }
 
 void field::call_listener () {
-	if (edited) {
-		if (expr) {
-			sprintf (BUFFER, "eval-expr %s %s", text.c_str(), type.c_str());
-			interpreter (BUFFER);
-			if (interpreter.result_status == 0) {
-				set_text (interpreter.result, 1);
-				if (change_lsnr) change_lsnr->changed (*this);
-			}
-		} else {
-			if (change_lsnr) change_lsnr->changed (*this);
-		}
-		edited = 0;
-	}
+  if (edited) {
+    if (expr) {
+      sprintf (BUFFER, "eval-expr %s %s", text.c_str(), type.c_str());
+      interpreter (BUFFER);
+      if (interpreter.result_status == 0) {
+        set_text (interpreter.result, 1);
+        if (change_lsnr) change_lsnr->changed (*this);
+      }
+    } else {
+      if (change_lsnr) change_lsnr->changed (*this);
+    }
+    edited = 0;
+  }
 }
