@@ -1,6 +1,6 @@
 /*
 * font.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -9,11 +9,14 @@
 #include <fstream>
 #include <sstream>
 #include <cmath>
+#include "log.h"
 #include "font.h"
+#include "random.h"
+#include "chrono.h"
+
 using namespace std;
 
 extern string user_data_dir;
-extern ofstream dlog;
 static const char eol = '\n';
 
 font::font (const string& filename) : mod(0)
@@ -40,7 +43,7 @@ font::font (const string& filename) : mod(0)
 #endif
 
 #ifdef __PLOTTER_FNT__
-	hpgl << "IN;" << eol;
+  hpgl << "IN;" << eol;
 #endif
 
 }
@@ -50,7 +53,7 @@ font::~font () {
 #ifdef __SVG_FNT__
   svg << "</svg>" << eol;
 #endif
-	dlog << "--- destroyed font ---" << endl;
+  dlog << "--- destroyed font ---" << endl;
 }
 
 void font::load (const string& fn) {
@@ -85,11 +88,11 @@ void font::load (ifstream& file) {
   for (int i = 0; i < nchars; i++) {
       char c; file >> c;
       glyph g;
-      int nln; file >> nln;
-      for (int l = 0; l < nln; ++l) {
+      file >> g.nln;
+      for (int l = 0; l < g.nln; ++l) {
         line ln;
-        int npts; file >> npts;
-        for (int s = 0; s < npts; ++s) {
+        file >> ln.npts;
+        for (int s = 0; s < ln.npts; ++s) {
           int x, y; file >> x >> y;
           ln.points.push_back (point<int>(x * cellsize.x, y * cellsize.y));
         }
@@ -113,7 +116,7 @@ void font::load (ifstream& file) {
 
   spacing.word = 2 * spacing.ch;
 
-	calc_line_height ();
+  calc_line_height ();
 
   int nkerns = 0;
   file >> ignore >> nkerns;
@@ -127,8 +130,8 @@ void font::load (ifstream& file) {
 }
 
 void font::calc_line_height () {
-	extern int line_height;
-	line_height = fnt.charheight.max + fnt.headroom;
+  extern int line_height;
+  line_height = fnt.charheight.max + fnt.headroom;
 }
 
 void font::save () {
@@ -136,8 +139,8 @@ void font::save () {
   ofstream file ((user_data_dir + fname).c_str(), ios::out);
   if (!file) { dlog << "cannot save font in: " << fname << eol; return;} else { dlog << "saving font in: " << fname << eol;}
 
-	// build chars
-	int nc = 0;
+  // build chars
+  int nc = 0;
   stringstream ss1;
   for (map<char, glyph>::iterator i = characters.begin(), j = characters.end(); i != j; ++i) {
     glyph& g = (*i).second;
@@ -160,14 +163,14 @@ void font::save () {
     }
   }
 
-	// write chars
+  // write chars
   file << "name " << name << eol;
-  file << "copyright jagannathan_sampath_(c)_2006-2021_all_rights_reserved." << eol;
+  file << "copyright jagannathan_sampath_(c)_2006-2026_all_rights_reserved." << eol;
   file << "num_chars " << nc << eol;
   file << ss1.str();
 
-	// build kerns
-	int nk = 0;
+  // build kerns
+  int nk = 0;
   stringstream ss2;
   for (map<char, map<char, int> >::iterator i = kern.begin(), j = kern.end(); i != j; ++i) {
     char a = (*i).first;
@@ -182,7 +185,7 @@ void font::save () {
     }
   }
 
-	// write kerns
+  // write kerns
   file << "num_kerns " << nk << eol;
   file << ss2.str();
 
@@ -192,35 +195,30 @@ int font::char_width (char c) { return characters[c].width;}
 int font::char_height (char c) { return characters[c].height;}
 
 void font::draw_char (char c, int x, int y, int z) {
-  const glyph& gl = characters[c];
-  const vector<line>& lines = gl.lines;
-  static const unsigned int MAX_LINE_POINTS = 128; // cant exceed or crash!
+  static const int MAX_LINE_POINTS = 32; // cant exceed or crash!
   static int pts [3 * MAX_LINE_POINTS] = {0};
+  glyph& gl = characters[c];
+  vector<line>& lines = gl.lines;
+
+  /*glColor3f (0.3, 0.3, 0.3);
+  int xl = x - cellsize.x, yl = y - cellsize.y;
+  glRecti (xl, yl, xl + charwidth.max + cellsize.x, yl + charheight.max + cellsize.y);*/
+
   glVertexPointer (3, GL_INT, 0, pts);
-  for (unsigned int i = 0, nlines = lines.size(); i < nlines; ++i) {
-    const line& li = lines[i];
-    const vector< point<int> >& points = li.points;
-    unsigned int npts = points.size();
-    int k = 0;
-    for (unsigned int j = 0; j < npts; ++j) {
+  for (int i = 0; i < gl.nln; ++i) {
+    line& li = lines[i];
+    vector< point<int> >& points = li.points;
+    int q = 0, npts = li.npts;
+    for (int j = 0; j < npts; ++j) {
       const point<int>& p = points[j];
-      pts[k++] = x + p.x;
-      pts[k++] = y + p.y;
-      pts[k++] = z;
+      pts[q++] = x + p.x;
+      pts[q++] = y + p.y;
+      pts[q++] = z;
     }
     glDrawArrays (GL_LINE_STRIP, 0, npts);
   }
 }
 
-const map<char, glyph>& font::get_chars () {
-  return characters;
-}
-
-void font::set_chars (const map<char, glyph>& chars) {
-  characters = chars;
-  mod = 1;
-}
-
 int draw_string (const string& s, int x, int y, int z) {
   char prevc = ' ';
   for (int p = 0, q = s.length(); p < q; ++p) {
@@ -235,16 +233,46 @@ int draw_string (const string& s, int x, int y, int z) {
   return x;
 }
 
+const map<char, glyph>& font::get_chars () {
+  return characters;
+}
+
+void font::set_chars (const map<char, glyph>& chars) {
+  characters = chars;
+  mod = 1;
+}
+
+void get_char_width_height (const string& s, int& x, int& y) {
+  x = 0; y = 0;
+  int q = s.length ();
+  if (q) {
+    char prevc = ' ';
+    for (int p = 0; p < q; ++p) {
+      char c = s[p];
+      if (c == ' ') 
+        x += fnt.spacing.word; 
+      else 
+        x = x + fnt.kern[prevc][c] + fnt.char_width (c) + fnt.spacing.ch;
+      int ch = fnt.char_height (c);
+      if (ch > y) y = ch;
+      prevc = c;
+    }
+  }
+}
+
 int get_char_width (const string& s) {
-  char prevc = ' ';
   int x = 0;
-  for (int p = 0, q = s.length(); p < q; ++p) {
-    char c = s[p];
-    if (c == ' ') 
-      x += fnt.spacing.word; 
-    else 
-      x = x + fnt.kern[prevc][c] + fnt.char_width (c) + fnt.spacing.ch;
-    prevc = c;
+  int q = s.length ();
+  if (q) {
+    char prevc = ' ';
+    for (int p = 0; p < q; ++p) {
+      char c = s[p];
+      if (c == ' ') 
+        x += fnt.spacing.word; 
+      else 
+        x = x + fnt.kern[prevc][c] + fnt.char_width (c) + fnt.spacing.ch;
+      prevc = c;
+    }
   }
   return x;
 }
@@ -268,9 +296,9 @@ void font::plot_char (char c, int x, int y, int z) {
     const line& li = lines[i];
     const vector< point<int> >& points = li.points;
     unsigned int npts = points.size();
-		const point<int>& p0 = points[0];
-		hpgl << "PU " << (x + p0.x) << ',' << (y + p0.y) << ';' << eol;
-		hpgl << "PD;" << eol;
+    const point<int>& p0 = points[0];
+    hpgl << "PU " << (x + p0.x) << ',' << (y + p0.y) << ';' << eol;
+    hpgl << "PD;" << eol;
     for (unsigned int j = 0; j < npts; ++j) {
       const point<int>& p = points[j];
       int xp = x + p.x, yp = y + p.y;
