@@ -1,6 +1,6 @@
 /*
 * font_editor.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -15,7 +15,7 @@
 using namespace std;
 
 font_editor::font_editor (font& f, const string& settingsf, const string& helpf) : 
-  curve_editor (settingsf, helpf), 
+  curve_editor (settingsf), 
   fn (f), 
   glyphs (f.get_chars()), 
   moving(false) {
@@ -100,7 +100,7 @@ int font_editor::handle_input () {
 
   basic_editor::handle_input ();
 
-	if (keypressed (SDLK_F1)) helptext ();
+  if (keypressed (SDLK_F1)) helptext ();
 
   if (keypressed (SDLK_f)) {
     float x, y; snap (x, y);
@@ -139,10 +139,6 @@ int font_editor::handle_input () {
     }
   }
 
-  if (keypressed (SDLK_g)) {
-    save_font ();
-  }
-
   if (keypressedd (SDLK_LEFTBRACKET)) {
     if (ichar > 0) {
       save_char (ichar--);
@@ -167,7 +163,7 @@ int font_editor::handle_input () {
 void font_editor::draw () {
   project ();
     basic_editor::draw ();
-		mark_area ();
+    mark_area ();
     draw_lines ();
     draw_scratch_line ();
   unproject ();
@@ -209,17 +205,17 @@ void font_editor::move () {
 }
 
 void font_editor::mark_area () {
-	glColor3f (0.5, 0.25, 0.25);
-	float wx, wy, ox = 0, oy = 2, owx, owy;
-	basic_editor::obj2win (fnt.charwidth.max / fnt.cellsize.x, fnt.charheight.max / fnt.cellsize.y, wx, wy);
-	basic_editor::obj2win (ox, oy, owx, owy);
-	glPolygonMode (GL_FRONT_AND_BACK, GL_LINE);
-		glRectf (0, 0, wx, wy);
-	glPolygonMode (GL_FRONT_AND_BACK, GL_FILL);
-	glBegin (GL_LINES);
-		glVertex2f (owx, owy);
-		glVertex2f (wx, owy);
-	glEnd ();
+  glColor3f (0.5, 0.25, 0.25);
+  float wx, wy, ox = 0, oy = 2, owx, owy;
+  basic_editor::obj2win (fnt.charwidth.max / fnt.cellsize.x, fnt.charheight.max / fnt.cellsize.y, wx, wy);
+  basic_editor::obj2win (ox, oy, owx, owy);
+  glPolygonMode (GL_FRONT_AND_BACK, GL_LINE);
+    glRectf (0, 0, wx, wy);
+  glPolygonMode (GL_FRONT_AND_BACK, GL_FILL);
+  glBegin (GL_LINES);
+    glVertex2f (owx, owy);
+    glVertex2f (wx, owy);
+  glEnd ();
 }
 
 
