@@ -1,17 +1,17 @@
 /*
 * globals.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
 
-
 #include "globals.h"
 #include "viewwin.h"
 #include "checkbutton.h"
 #include "random.h"
 #include "log.h"
 #include "curve_editor.h"
+
 #include <map>
 #include <iostream>
 
@@ -26,14 +26,17 @@ extern string VARSTR;
 extern int VAR_MIN2, VAR_MAX2;
 extern std::string VARSTR2;
 extern char BUFFER [];
+extern const char* INDIAN_SWAR [];
+extern map<string, string> INT2IND;
 
-extern int NUM_OCTAVES;
 extern string user_data_dir;
 
 int load_globals::load_intervals (const string& fname) {
 
   ifstream file ((user_data_dir + fname).c_str(), ios::in);
+
   if (file) {
+
     INTERVALS_FILE = fname;
 
     file >> ignore >> NUM_INTERVALS;
@@ -42,17 +45,19 @@ int load_globals::load_intervals (const string& fname) {
     INTERVAL_NAMES.clear ();
     INTERVAL_VALUES.clear ();
 
+    string interval_name;
+    float value;
     for (int i = 0, pos = 0; i < NUM_INTERVALS; ++i) {
-      string note_name;
-      float value;
-      file >> note_name >> value;
-      INTERVALS [note_name] = value;
-      NOTE_POS [note_name] = pos++;
-      INTERVAL_NAMES.push_back (note_name);
+      file >> interval_name >> value;
+      INTERVALS [interval_name] = value;
+      NOTE_POS [interval_name] = pos++;
+      INTERVAL_NAMES.push_back (interval_name);
       INTERVAL_VALUES.push_back (value);
+      INT2IND[interval_name] = INDIAN_SWAR[i];
     }
 
     return 1;
+
   } else return 0;
 
 }
@@ -66,25 +71,26 @@ load_globals::load_globals () {
 
     file >> ignore >> viewport::handle_radius;
 
-		file >> ignore >> widget::R >> widget::G >> widget::B;
-		file >> ignore >> checkbutton::on_color.r >> checkbutton::on_color.g >> checkbutton::on_color.b; 
-		file >> ignore >> checkbutton::off_color.r >> checkbutton::off_color.g >> checkbutton::off_color.b;
-		file >> ignore >> curve_editor::vtxlbl.r >> curve_editor::vtxlbl.g >> curve_editor::vtxlbl.b;
+    file >> ignore >> widget::R >> widget::G >> widget::B;
+    file >> ignore >> checkbutton::on_color.r >> checkbutton::on_color.g >> checkbutton::on_color.b; 
+    file >> ignore >> checkbutton::off_color.r >> checkbutton::off_color.g >> checkbutton::off_color.b;
+    file >> ignore >> curve_editor::vtxlbl.r >> curve_editor::vtxlbl.g >> curve_editor::vtxlbl.b;
 
-		extern rnd<int> RAN_MOD_BPM;
-		float rmb1, rmb2;
-		file >> ignore >> rmb1 >> rmb2; RAN_MOD_BPM = rnd<int> (rmb1, rmb2);
+    extern rnd<int> RAN_MOD_BPM;
+    float rmb1, rmb2;
+    file >> ignore >> rmb1 >> rmb2; RAN_MOD_BPM = rnd<int> (rmb1, rmb2);
 
-		file >> ignore >> VAR_MIN >> VAR_MAX;
-		sprintf (BUFFER, "%d %d", VAR_MIN, VAR_MAX); 
-		VARSTR = BUFFER;
+    file >> ignore >> VAR_MIN >> VAR_MAX;
+    sprintf (BUFFER, "%d %d", VAR_MIN, VAR_MAX); 
+    VARSTR = BUFFER;
 
     file >> ignore >> VAR_MIN2 >> VAR_MAX2;
     sprintf (BUFFER, "%d %d", VAR_MIN2, VAR_MAX2); 
     VARSTR2 = BUFFER;
 
     load_intervals (INTERVALS_FILE);
-		dlog << "loaded globals from: " << fname << endl;
+
+    dlog << "loaded globals from: " << fname << endl;
   } else {
     dlog << "!!! could not load globals !!!" << endl;
   }
