@@ -1,6 +1,6 @@
 /*
 * globals.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -31,19 +31,22 @@ template <class T> struct pusher {
 
 #include <iostream>
 
+extern const char spc;
+
 template<class T> void into_lines (const std::string& str, pusher<T>& push) {
 
   static tokenizer tz;
-  static const std::string newline = "\n";
   static const char endln = '\n';
 
   if (str.length()) {
-    tz.set (str, newline);
+    tz.str (str);
+    tokenizer::delim = endln;
     std::string ln;
     while (1) {
-      std::string ln; tz >> ln;
+      tz >> ln;
       if (ln == "") break; else { push << ln << endln; }
     }
+    tokenizer::delim = spc;
   }
 }
 
