@@ -1,6 +1,6 @@
 /*
 * hit.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -15,7 +15,7 @@ hit_t::hit_t (multi_curve* cv, int cid, int w, int i, int no)  {
   crv_id = cid;
   what = w;
   id = i;
-	name_only = no;
+  name_only = no;
 }
 
 void hit_t::clear () {
@@ -23,7 +23,7 @@ void hit_t::clear () {
   crv_id = -1;
   what = NONE;
   id = -1;
-	name_only = 0;
+  name_only = 0;
 }
 
 int hit_t::operator()() const { // hit some curve?
@@ -31,13 +31,13 @@ int hit_t::operator()() const { // hit some curve?
 }
 
 int hit_t::operator()(int) const { // hit an existing curve item?
-	return (crv_id != -1 && (id > -1) && (id < crv->num_vertices));
+  return (crv_id != -1 && (id > -1) && (id < crv->num_vertices));
 }
 
-const point<float>& hit_t::get () {
-	points_array* ptr[3] = {&crv->vertices, &crv->left_tangents, &crv->right_tangents};
-	points_array& arr = *ptr[what-1];
-	return arr[id];
+pointinfo<float>& hit_t::get () {
+  points_array* ptr[3] = {&crv->vertices, &crv->left_tangents, &crv->right_tangents};
+  points_array& arr = *ptr[what-1];
+  return arr[id];
 }
 
 hit_t::hit_t (const hit_t& src) {
@@ -63,6 +63,6 @@ void hit_t::copy (const hit_t& src) {
 }
 
 void hit_t::ensure_id () {
-	if (id < 0) id = 0;
-	else if (id > crv->last_vertex) id = crv->last_vertex;
+  if (id < 0) id = 0;
+  else if (id > crv->last_vertex) id = crv->last_vertex;
 }
