@@ -1,6 +1,6 @@
 /*
 * keyboard_keyboard.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -10,7 +10,7 @@
 #include "input.h"
 #include "ui_list.h"
 #include "audio.h"
-#include "din.h"
+#include "microtonal-keyboard.h"
 #include "audio.h"
 #include "midi_in.h"
 #include <math.h>
@@ -22,7 +22,6 @@ using namespace std;
 
 extern int mousex, mousey, mouseyy;
 
-extern din din0;
 extern beat2value octave_shift;
 
 extern float ATTACK_TIME, DECAY_TIME;
@@ -42,6 +41,11 @@ typedef list<triggered_note>::iterator triggered_note_iterator;
 
 extern int UI_OFF;
 
+extern const char* INDIAN_SWAR [];
+extern map<string, string> INT2IND;
+
+extern int JUSTIFICATION;
+
 void keyboard_keyboard::setup () {
 
   vector<key_info> ki;
@@ -75,7 +79,7 @@ void keyboard_keyboard::setup () {
     scale2keybd [i] = ki;
   }  
 
-	// setup waveform
+  // setup waveform
   waved.add (&wave, &wavlis);
   waved.attach_library (&wav_lib);
 
@@ -91,32 +95,32 @@ void keyboard_keyboard::setup () {
 
   // setup velocity curve (used on MIDI triggered notes)
   velsol (&velcrv);
-	veled.add (&velcrv, &vellis);
+  veled.add (&velcrv, &vellis);
   veled.attach_library (&vellib);
 
   // initial mouse position
-  prev_mousex = view.xmax / 2;
-  prev_mousey = view.ymax / 2;
+  prev_mousex = view.midx;
+  prev_mousey = view.midy;
 
 }
 
 keyboard_keyboard::~keyboard_keyboard () {
-	scaleinfo.save_scale ();
+  scaleinfo.save_scale ();
   wave.save ("keyboard-keyboard-waveform.crv");
   attackcrv.save ("attack.crv");
   decaycrv.save ("decay.crv");
   velcrv.save ("velocity.crv");
-	ofstream file ((user_data_dir + fname).c_str(), ios::out);
-	if (!file) {
-		dlog << "!!! couldnt save : " << fname << endl;
-	} else {
-		file << "show_nearby_notes " << show_nearby_notes << endl;
-		file << "attack_time " << ATTACK_TIME << endl;
-		file << "decay_time " << DECAY_TIME << endl;
-		file << "note_volume " << NOTE_VOLUME << endl;
-		file << "pitch_bend " << PITCH_BEND << endl;
-		file << "trig_what " << trig_what << endl;
-	}
+  ofstream file ((user_data_dir + fname).c_str(), ios::out);
+  if (!file) {
+    dlog << "!!! couldnt save : " << fname << endl;
+  } else {
+    file << "show_nearby_notes " << show_nearby_notes << endl;
+    file << "attack_time " << ATTACK_TIME << endl;
+    file << "decay_time " << DECAY_TIME << endl;
+    file << "note_volume " << NOTE_VOLUME << endl;
+    file << "pitch_bend " << PITCH_BEND << endl;
+    file << "trig_what " << trig_what << endl;
+  }
   dlog << "--- destroyed keyboard-keyboard ---" << endl;
 }
 
@@ -131,9 +135,9 @@ void keyboard_keyboard::bg () {
 
 int keyboard_keyboard::handle_input () {
 
-  din0.dinfo.delay = uis.cb_delay.is_on ();
+  mkb.dinfo.delay = uis.cb_delay.state;
 
-	mouse_bend (); // pitch bend via mouse x movement
+  mouse_bend (); // pitch bend via mouse x movement
 
   // trigger notes
   //
@@ -148,14 +152,14 @@ int keyboard_keyboard::handle_input () {
     }
   }
 
-	if (keypressed (SDLK_RETURN)) {
-		trig_what = !trig_what;
-		extern const char* keys_trig_what [];
-		set_label (uis.ol_trig_what.option, keys_trig_what, trig_what);
-	}
+  if (keypressed (SDLK_RETURN)) {
+    trig_what = !trig_what;
+    extern const char* keys_trig_what [];
+    set_label (uis.ol_trig_what.option, keys_trig_what, trig_what);
+  }
 
   if (keypressed (SDLK_SPACE)) 
-		turn_off_bend (); // turn of mouse based pitch bending
+    turn_off_bend (); // turn of mouse based pitch bending
 
   // octave shift
   else if (keypressed (SDLK_z)) modulate_down ();
@@ -169,7 +173,7 @@ int keyboard_keyboard::handle_input () {
   } 
   else if (keypressed (SDLK_n)) abort_octave_shift (this);
 
-	// browse waveforms
+  // browse waveforms
   if (!mouse_slider0.active) {
     if (keypressedd (SDLK_9)) uis.wdl.clicked (uis.ab_prev_wav); else 
     if (keypressedd (SDLK_0)) uis.wdl.clicked (uis.ab_next_wav);
@@ -201,14 +205,15 @@ void keyboard_keyboard::setup_notes (int overwrite) {
 
   extern map<std::string, float> INTERVALS; // tuning
   extern const char* WESTERN_FLAT [];
-	extern map<std::string, int> NOTE_POS; // inteval -> pos on chromatic scale
+  extern map<std::string, int> NOTE_POS; // inteval -> pos on chromatic scale
   extern int NOTATION; // current notation
   int western = scaleinfo.western; // index of key in the chromatic scale
 
   string tonic_name;
   if (NOTATION == WESTERN) {
     tonic_name = WESTERN_FLAT [western]; // note on the chromatic scale
-  } else tonic_name = "1"; 
+  } else if (NOTATION == NUMERIC) tonic_name = "1"; 
+  else tonic_name = INDIAN_SWAR[0];
 
   for (int i = 0; i < noct; ++i) {
     for (int j = 0; j < num_notes; ++j) {
@@ -216,9 +221,10 @@ void keyboard_keyboard::setup_notes (int overwrite) {
       notes.push_back (note());
       note& last = notes [notes.size() - 1];
       if (NOTATION == WESTERN) {
-			  int k = (western + NOTE_POS [name]) % 12;
+        int k = (western + NOTE_POS [name]) % 12;
         last.name = WESTERN_FLAT [k];
-      } else last.name = name;
+      } else if (NOTATION == NUMERIC) last.name = name;
+      else last.name = INT2IND[name];
       last.set_freq (tonic * INTERVALS [name]);
     }
     tonic *= 2; // next octave
@@ -252,18 +258,21 @@ void keyboard_keyboard::attack_note (int ky) { // also trigger note
 
   marker_x = mousex;
 
-	int last_trig_x = ki.x;
+  int last_trig_x = ki.x;
   int last_trig_y = ki.y;
-	if (show_nearby_notes) { // position note display at cursor
+  if (show_nearby_notes) { // position note display at cursor
     last_trig_x = mousex; 
     last_trig_y = mouseyy;
-		if (num_triggered_notes) turn_off_bend (); // stop bending all previous notes, will only bend the last note
+    if (num_triggered_notes) turn_off_bend (); // stop bending all previous notes, will only bend the last note
   }
 
-  triggered_notes.push_back (triggered_note (n, NOTE_VOLUME, last_trig_x, last_trig_y, trig_what, ky, marker_x));
-	triggered_note& last_triggered_note = triggered_notes.back (); 
-	last_triggered_note.setup (&wave, &attackcrv, &decaycrv);
+  int bin = is_din_binaural ();
+  float sep = 0.0f; if (bin) sep = get_binaural_separation_in_hz ();
+  triggered_notes.push_back ( triggered_note (n, NOTE_VOLUME, last_trig_x, last_trig_y, trig_what, bin, JUSTIFICATION, sep, ky, marker_x));
+  triggered_note& last_triggered_note = triggered_notes.back (); 
+  last_triggered_note.setup (&wave, &attackcrv, &decaycrv);
   ++num_triggered_notes;
+
 }
 
 void keyboard_keyboard::decay_note (int ky) {
@@ -281,21 +290,24 @@ void keyboard_keyboard::update_decay () {
   for (triggered_note_iterator i = triggered_notes.begin (), j = triggered_notes.end (); i != j; ++i) (*i).decay.update ();
 }
 
-void keyboard_keyboard::update_waveform (multi_curve& crv) {
-  for (triggered_note_iterator i = triggered_notes.begin (), j = triggered_notes.end (); i != j; ++i) (*i).update_solver (crv);
-  uis.cd_waveform_display.calc_bbox ();
+void keyboard_keyboard::update_waveform (multi_curve& src) {
+  static const string nam ("keyboard-keyboard-waveform");
+  for (triggered_note_iterator i = triggered_notes.begin (), j = triggered_notes.end (); i != j; ++i) 
+    (*i).update_solver (src, nam);
+  uis.cd_waveform_display.setbbox (wave.shapeform);
 }
 
+
 int keyboard_keyboard::render_audio (float* L, float* R) {
-	int ret = 0;
+  int ret = 0;
   for (triggered_note_iterator i = triggered_notes.begin (), j = triggered_notes.end (); i != j; ++i) {
     triggered_note& ti = *i;
     if (ti.state != triggered_note::FINISHED) {
-			ti.eval (L, R, aout.result, aout.vol, aout.samples_per_channel, ATTACK_TIME, DECAY_TIME, _gotog);
-			ret += ti.player.mixer.active;
-		}
+      ti.eval (L, R, aout.result, aout.vol, aout.samples_per_channel, ATTACK_TIME, DECAY_TIME, _gotog);
+      ret += ti.player.mixer.active;
+    }
   }
-	return ret;
+  return ret;
 }
 
 void keyboard_keyboard::remove_finished_notes () {
@@ -309,13 +321,13 @@ void keyboard_keyboard::remove_finished_notes () {
 }
 
 void keyboard_keyboard::calc_visual_params () {
-	int nkeys = keys.size ();
-	int key_width = 2 * fnt.charwidth.avg * fnt.cellsize.x + 3;
-	int press_width = get_char_width ("Press  "); // in pixels
-	int print = press_width + key_width * nkeys;
-	pressx = (int) ((view.xmax - print) / 2 + 0.5f);
-	hearx = pressx;
-	int x = pressx + press_width;
+  int nkeys = keys.size ();
+  int key_width = 2 * fnt.charwidth.avg * fnt.cellsize.x + 3;
+  int press_width = get_char_width ("Press  "); // in pixels
+  int print = press_width + key_width * nkeys;
+  pressx = (int) ((view.xmax - print) / 2 + 0.5f);
+  hearx = pressx;
+  int x = pressx + press_width;
   int half_height = view.ymax / 2;
   for (int i = 0; i < nkeys; ++i) {
     key_info& ki = keys[i];
@@ -329,7 +341,7 @@ void keyboard_keyboard::calc_visual_params () {
 
   int lh = (int) (1.5f * line_height + 0.5f);
   ymarker = (int) (1.25f * lh + 0.5f);
-	ynotes = (int)(ymarker + 0.75f * lh + 0.5f);
+  ynotes = (int)(ymarker + 0.75f * lh + 0.5f);
   ychars = (int)(ynotes + lh);
 
   if (nkeys) spacing = (view.width - 2 * keys[0].x) / 12;
@@ -345,7 +357,7 @@ void keyboard_keyboard::draw () {
   glMatrixMode (GL_MODELVIEW);
   glLoadIdentity ();
 
-	// draw triggerred notes
+  // draw triggerred notes
   glEnable (GL_BLEND);
   glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
@@ -367,17 +379,17 @@ void keyboard_keyboard::draw () {
     pts[2]=xp;pts[3]=ym;
     pts[4]=xp;pts[5]=yp;
     pts[6]=xm;pts[7]=yp;
-		glVertexPointer(2, GL_INT, 0, pts);
+    glVertexPointer(2, GL_INT, 0, pts);
     glDrawArrays (GL_LINE_LOOP, 0, 4);
     glLineWidth (1);
 
   }
   glDisable (GL_BLEND);
 
-	if (UI_OFF) return;
+  if (UI_OFF) return;
 
-  glColor3f (0.25, 0.25, 0.25);
   if (midiin.available) { // mark midi notes
+    glColor3f (0.25, 0.25, 0.25);
     int startx = keys[0].x, starty = keys[0].y;
     int marker = 15;
     glVertexPointer (2, GL_INT, 0, pts);
@@ -393,7 +405,7 @@ void keyboard_keyboard::draw () {
 
   glEnable (GL_LINE_STIPPLE);
   glLineStipple (1, 0xFFF0);
-	glColor3f (0.75, 0.75, 0.75);
+  glColor3f (0.75, 0.75, 0.75);
 
   if (num_triggered_notes) {
     if (show_nearby_notes) { // mark notes near to cursor
@@ -403,42 +415,54 @@ void keyboard_keyboard::draw () {
         float dhz = ni.hz - recent_note_hz;
         int npix = (int) (dhz / PITCH_BEND_PER_PIXEL + 0.5);
         int marker_nx = marker_x + npix;
-        pts[0]=marker_nx;pts[1]=0;
+        /*pts[0]=marker_nx;pts[1]=0;
         pts[2]=marker_nx;pts[3]=view.ymax;
         glVertexPointer (2, GL_INT, 0, pts);
-        glDrawArrays (GL_LINES, 0, 2);
+        glDrawArrays (GL_LINES, 0, 2);*/
+        glBegin (GL_LINES);
+          glVertex2i (marker_nx, 0);
+          glVertex2i (marker_nx, view.ymax);
+        glEnd ();
         glDisable (GL_LINE_STIPPLE);
           draw_string (ni.name, marker_nx, ki.y);
           fnt.draw_char (ki.ch, marker_nx, ki.y + line_height);
         glEnable (GL_LINE_STIPPLE);
-    	}
-  	} else {
-    	// mark 0 pitch bend
-    	pts[0]=marker_x;pts[1]=0;
-    	pts[2]=marker_x;pts[3]=view.ymax;
-    	glVertexPointer (2, GL_INT, 0, pts);
-    	glDrawArrays (GL_LINES, 0, 2);
-  	}
+      }
+    } else {
+      // mark 0 pitch bend
+      /*pts[0]=marker_x;pts[1]=0;
+      pts[2]=marker_x;pts[3]=view.ymax;
+      glVertexPointer (2, GL_INT, 0, pts);
+      glDrawArrays (GL_LINES, 0, 2);*/
+      glBegin (GL_LINES);
+        glVertex2i (marker_x, 0);
+        glVertex2i (marker_x, view.ymax);
+      glEnd ();
+    }
   }
   glLineWidth (1);
   glDisable (GL_LINE_STIPPLE);
 
-	// show press keys & hear notes
-	static const string PRESS = "Press  ", HEAR = " Hear ";
-	glColor3f (1, 1, 1);
-		draw_string (PRESS, pressx, ychars);
-		draw_string (HEAR, hearx, ynotes);
+  // show press keys & hear notes
+  static const string PRESS = "Press  ", HEAR = " Hear ";
+  glColor3f (1, 1, 1);
+    draw_string (PRESS, pressx, ychars);
+    draw_string (HEAR, hearx, ynotes);
   for (int i = 0, j = keys.size (); i < j; ++i) {
     key_info& ki = keys[i];
-		note& ni = notes[i];
+    note& ni = notes[i];
     glColor3f (ki.r, ki.g, ki.b);
     fnt.draw_char (ki.ch, ki.x, ychars);
-		draw_string (ni.name, ki.x, ynotes);
+    draw_string (ni.name, ki.x, ynotes);
     if (ki.attacked) { // hilite key that triggered last note
-      pts[0]=ki.x;pts[1]=ymarker;
+      glBegin (GL_LINES);
+        glVertex2i (ki.x, ymarker);
+        glVertex2i (ki.x + fnt.charwidth.max, ymarker);
+      glEnd ();
+      /*pts[0]=ki.x;pts[1]=ymarker;
       pts[2]=ki.x+fnt.charwidth.max;pts[3]=ymarker;
       glVertexPointer (2, GL_INT, 0, pts);
-      glDrawArrays (GL_LINES, 0, 2);
+      glDrawArrays (GL_LINES, 0, 2);*/
     }
   }
 
@@ -474,21 +498,19 @@ void keyboard_keyboard::note_on (unsigned char id, unsigned char vel) {
   }
 
   note& n = midi_notes [id];
-	int i12 = id % 12;
+  int i12 = id % 12;
 
   marker_x = mousex;
-  triggered_notes.push_back (triggered_note (n, velsol(vel) * NOTE_VOLUME, keys[0].x + i12 * spacing, keys[0].y, trig_what, id, marker_x));
-	triggered_note& last_triggered_note = *(--triggered_notes.end());
-	last_triggered_note.setup (&wave, &attackcrv, &decaycrv);
 
-	/*int ci = color_index [i12];
-	float r = note_color[ci].r;
-	float g = note_color[ci].g;
-	float b = note_color[ci].b;
-	last_triggered_note.r = r; last_triggered_note.g = g; last_triggered_note.b = b;*/
+  int bin = is_din_binaural ();
+  float sep = 0.0f; if (bin) sep = get_binaural_separation_in_hz ();
 
-
-	++num_triggered_notes;
+  triggered_notes.push_back (
+    triggered_note (n, velsol(vel) * NOTE_VOLUME, keys[0].x + i12 * spacing, keys[0].y, trig_what, bin, JUSTIFICATION, sep, id, marker_x)
+  );
+  triggered_note& last_triggered_note = *(--triggered_notes.end());
+  last_triggered_note.setup (&wave, &attackcrv, &decaycrv);
+  ++num_triggered_notes;
 
 }
 
@@ -497,7 +519,7 @@ void keyboard_keyboard::note_off (unsigned char id) {
 }
 
 void keyboard_keyboard::pitch_bend (float v) { 
-	for (triggered_note_iterator i = triggered_notes.begin (), j = triggered_notes.end (); i != j; ++i) {
+  for (triggered_note_iterator i = triggered_notes.begin (), j = triggered_notes.end (); i != j; ++i) {
     triggered_note& ti = *i;
     float pv = PITCH_BEND * v;
     ti.set_freq (ti.start_hz + pv);
@@ -514,10 +536,10 @@ void keyboard_keyboard::calc_mouse_bend (triggered_note& ti) {
 
 void keyboard_keyboard::mouse_bend () {
   if (mousex != prev_mousex) {
-  	for (triggered_note_iterator i = triggered_notes.begin (), j = triggered_notes.end (); i != j; ++i) {
-    	triggered_note& ti = *i;
-			if (ti.bend) calc_mouse_bend (ti);
-		}
+    for (triggered_note_iterator i = triggered_notes.begin (), j = triggered_notes.end (); i != j; ++i) {
+      triggered_note& ti = *i;
+      if (ti.bend) calc_mouse_bend (ti);
+    }
     prev_mousex = mousex;
   }
 }
@@ -527,22 +549,22 @@ void keyboard_keyboard::enter () {
 }
 
 void keyboard_keyboard::tonic_changed () {
-	setup_notes (0);
-	calc_visual_params ();
+  setup_notes (0);
+  calc_visual_params ();
 }
 
 void keyboard_keyboard::scale_changed () {
-	load_scale ();
+  load_scale ();
 }
 
 void keyboard_keyboard::scale_loaded () {
-	load_scale ();
+  load_scale ();
 }
 
 void keyboard_keyboard::load_scale (int dummy) {
-	setup_notes ();
-	setup_midi_notes ();
-	calc_visual_params ();
+  setup_notes ();
+  setup_midi_notes ();
+  calc_visual_params ();
 }
 
 int keyboard_keyboard::turn_off_bend () {
@@ -550,5 +572,5 @@ int keyboard_keyboard::turn_off_bend () {
     triggered_note& ti = *i;
     ti.bend = 0; // turn of mouse based pitch bending
   }
-	return 0;
+  return 0;
 }
