@@ -1,6 +1,6 @@
 /*
 * levels.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -24,8 +24,8 @@ extern int line_height;
 
 levels::levels (const string& s) {
   name = s;
-	editing = lmb_clicked = paint = nsel = 0;
-	selection = 0;
+  editing = lmb_clicked = paint = nsel = 0;
+  selection = 0;
   chgl = 0;
   shftl = 0;
   paintl = 0;
@@ -58,7 +58,7 @@ levels::levels (const string& s) {
 levels::~levels () {
   save ();
   removeallbookmarks ();
-	if (selection) delete[] selection;
+  if (selection) delete[] selection;
 }
 
 void levels::load () {
@@ -79,7 +79,7 @@ void levels::load () {
   file >> ignore >> w;
   cbwrap.set_state (w,0);
 
-	a = 0.7;
+  a = 0.7;
   a0 = a / 4;
   extents (left, bottom, left + n * elem, bottom + height);
   set_pos (left, bottom);
@@ -87,9 +87,9 @@ void levels::load () {
   values.resize (n);
   heights.resize (n);
 
-	selection = new bool [n];
-	sel_sz = sizeof (bool) * n;
-	memset (selection, 0, sel_sz);
+  selection = new bool [n];
+  sel_sz = sizeof (bool) * n;
+  memset (selection, 0, sel_sz);
 
   if (saveable) {
     int savings;
@@ -99,7 +99,7 @@ void levels::load () {
       heights[i] = h;
       values[i] =  h * extents.height_1;
     }
-		file >> nsel;
+    file >> nsel;
   }
 
   int nb;
@@ -134,11 +134,11 @@ void levels::save () {
     file << "height " << height << endl;
     file << "editable " << editable << endl;
     file << "saveable " << saveable << endl;
-		file << "wrap " << cbwrap.state << endl;
+    file << "wrap " << cbwrap.state << endl;
     if (saveable) {
       file << "savings " << n << spc;
       for (int i = 0; i < n; ++i) file << heights[i] << spc << selection[i] << spc;
-			file << nsel << endl;
+      file << nsel << endl;
     } else {
       file << "savings 0" << endl;
     }
@@ -158,98 +158,105 @@ void levels::save () {
 }
 
 int levels::stop_editing () {
-	if (editing == FINISH) {
-		editing = 0;
-		return 1;
-	}
-	return 0;
+  if (editing == FINISH) {
+    editing = 0;
+    return 1;
+  }
+  return 0;
 }
 
 int levels::handle_input () {
 
-	prev_mousey = mousey;
+  prev_mousey = mousey;
 
   widget::handle_input ();
 
-	int hne = hover && !editing;
-	if (hne) calc_lev (); 
+  int hne = hover && !editing;
+  if (hne) calc_lev (); 
 
-  if (keypressed (SDLK_f)) {
-    paint = !paint;
-    if (paintl) paintl->paint (*this);
-  }
 
-	if (editable) {
+  if (editable) {
+
+    /*if (keypressed (SDLK_f)) {
+      paint = !paint;
+      if (paintl) paintl->paint (*this);
+    } else*/ 
+
+    if (keypressedd (SDLK_LEFT)) {
+      lshift ();
+    } else if (keypressedd (SDLK_RIGHT)) {
+      rshift ();
+    }
 
     for (int i = 0, j = children.size(); i < j; ++i) {
       if (children[i]->handle_input ()) return 1;
     }
 
-		if (lmb) {
-			if (lmb_clicked == 0) {
-				if (stop_editing () == 0) {
-					if (hne) {
-						if (SHIFT) {
-							bool& k = selection [lev];
-							k = !k;
-							if (k) ++nsel; else --nsel;
-						} else {
-							editing = STARTED;
-							widget::focus = this;
-						}
-					}
-				}
-			}
-			lmb_clicked = 1;
-		} else { 
+    if (lmb) {
+      if (lmb_clicked == 0) {
+        if (stop_editing () == 0) {
+          if (hne) {
+            if (SHIFT) {
+              bool& k = selection [lev];
+              k = !k;
+              if (k) ++nsel; else --nsel;
+            } else {
+              editing = STARTED;
+              widget::focus = this;
+            }
+          }
+        }
+      }
+      lmb_clicked = 1;
+    } else { 
 
-			lmb_clicked = 0;
-			if (editing) {
+      lmb_clicked = 0;
+      if (editing) {
 
-				if (wheel) {
-					mousey -= wheel; 
-					warp_mouse (mousex, mousey);
-				}
+        if (wheel) {
+          mousey -= wheel; 
+          warp_mouse (mousex, mousey);
+        }
 
-				if (paint) calc_lev ();
+        if (paint) calc_lev ();
 
-				calc_hgt_val ();
+        calc_hgt_val ();
 
-				int dh = set (lev, val, hgt);
-				int uml = 0;
-				if (selection[lev] && !SHIFT ) uml = update_mul_lev (dh);
-				if (chgl && (dh || uml)) chgl->changed (*this);
+        int dh = set (lev, val, hgt);
+        int uml = 0;
+        if (selection[lev] && !SHIFT ) uml = update_mul_lev (dh);
+        if (chgl && (dh || uml)) chgl->changed (*this);
 
-				editing = FINISH;
+        editing = FINISH;
 
-			} else {
-				if (widget::focus == this) widget::focus = 0;
-			}
-		}
-	}
+      } else {
+        if (widget::focus == this) widget::focus = 0;
+      }
+    }
+  }
 
   return 1;
 
 }
 
 int levels::update_mul_lev (int dh) {
-	float dv = dh * extents.height_1;
-	int ret = 0;
-	for (int i = 0; i < n; ++i) {
-		if ((i != lev) && selection[i]) {
-			int& hi = heights[i];
-			float& vi = values[i];
-			int hji = hi + dh; 
-			float vji = vi + dv;
+  float dv = dh * extents.height_1;
+  int ret = 0;
+  for (int i = 0; i < n; ++i) {
+    if ((i != lev) && selection[i]) {
+      int& hi = heights[i];
+      float& vi = values[i];
+      int hji = hi + dh; 
+      float vji = vi + dv;
 
-			if (hji < 0) hji = 0; else if (hji > extents.height) hji = extents.height;
-			if (vji < 0.0f) vji = 0.0f; else if (vji > 1.0f) vji = 1.0f;
-			hi = hji;
-			vi = vji;
-			ret = 1;
-		}
-	}
-	return ret;
+      if (hji < 0) hji = 0; else if (hji > extents.height) hji = extents.height;
+      if (vji < 0.0f) vji = 0.0f; else if (vji > 1.0f) vji = 1.0f;
+      hi = hji;
+      vi = vji;
+      ret = 1;
+    }
+  }
+  return ret;
 }
 
 void levels::calc_lev () {
@@ -259,7 +266,7 @@ void levels::calc_lev () {
 
 void levels::calc_hgt_val () {
   hgt = mouseyy - extents.bottom;
-	clamp<int> (0, hgt, extents.height);
+  clamp<int> (0, hgt, extents.height);
   val = hgt * extents.height_1;
 }
 
@@ -269,6 +276,15 @@ void levels::clear_hgt_val () {
 
 void levels::draw () {
 
+  if (editing) {
+    glColor3f (.5f, .5f, .5f);
+    int ybh = extents.bottom + hgt;
+    glBegin (GL_LINES);
+      glVertex2i (extents.left, ybh);
+      glVertex2i (extents.right, ybh);
+    glEnd ();
+  }
+
   glEnable (GL_BLEND);
   glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     int i = 0, x = extents.left, ds = elem - 2;
@@ -281,7 +297,7 @@ void levels::draw () {
       glColor4f (clr.r, clr.g, clr.b, a0);
         glRecti (l, extents.bottom, r, extents.top);
 
-			float dc = selection[i] * 0.4;
+      float dc = selection[i] * 0.4;
       glColor4f (clr.r + dc * clr.r, clr.g + dc * clr.g, clr.b + dc * clr.b, a);
         glRecti (l, extents.bottom, r, extents.bottom + heights[i]);
       x += elem;
@@ -298,40 +314,40 @@ void levels::draw () {
 }
 
 int levels::change (int i, float dv) {
-	if (i > -1 && i < n) {
-		float& vi = values[i];
-		vi += dv;
-		int result = clamp<float> (0, vi, 1);
-		heights[i] = (int) (vi * extents.height + 0.5); 
-		return result;
-	}
-	return 0;
+  if (i > -1 && i < n) {
+    float& vi = values[i];
+    vi += dv;
+    int result = clamp<float> (0, vi, 1);
+    heights[i] = (int) (vi * extents.height + 0.5); 
+    return result;
+  }
+  return 0;
 }
 
 void levels::set_only (int i, float v) { 
-	if (i > -1 && i < n) {
-		clamp<float> (0, v, 1);
-		values[i] = v;
-		heights[i] = (int)(v * extents.height + 0.5);
-	}
+  if (i > -1 && i < n) {
+    clamp<float> (0, v, 1);
+    values[i] = v;
+    heights[i] = (int)(v * extents.height + 0.5);
+  }
 }
 
 int levels::set (int i, float v, int h) { // from ui
   if (i > -1 && i < n) {
-		int& hi = heights[i];
-		int dh = h - hi;
-		hi = h;
-		float& vi = values[i];
-		if (vi != v) { // bcos from ui
-			vi = v;
-		}
-		return dh;
+    int& hi = heights[i];
+    int dh = h - hi;
+    hi = h;
+    float& vi = values[i];
+    if (vi != v) { // bcos from ui
+      vi = v;
+    }
+    return dh;
   }
-	return 0;
+  return 0;
 }
 
 void levels::update () {
-	if (chgl) chgl->changed (*this);
+  if (chgl) chgl->changed (*this);
 }
 
 void levels::chkpos () {
@@ -340,106 +356,106 @@ void levels::chkpos () {
 }
 
 void levels::reheight () {
-	for (int i = 0; i < n; ++i) {
-		float v = values[i];
-		int h = v * height + 0.5;
-		heights[i] = h;
-	}
+  for (int i = 0; i < n; ++i) {
+    float v = values[i];
+    int h = v * height + 0.5;
+    heights[i] = h;
+  }
 }
 
 int levels::lshift () { 
 
-	float v0 = values[0];
-	int h0 = heights[0];
+  float v0 = values[0];
+  int h0 = heights[0];
 
   int wrap = cbwrap.state;
 
-	if (wrap == 0) {
-		if (h0) return 0;
-	}
+  if (wrap == 0) {
+    if (h0) return 0;
+  }
 
-	for (int i = 0, j = 1; i < last; ++i, ++j) {
-		values[i] = values[j];
-		heights[i] = heights[j];
-	}
+  for (int i = 0, j = 1; i < last; ++i, ++j) {
+    values[i] = values[j];
+    heights[i] = heights[j];
+  }
 
   float& vl = values[last];
   int& hl = heights[last];
-	if (wrap) {
-		vl = v0;
-		hl = h0;
-	} else {
+  if (wrap) {
+    vl = v0;
+    hl = h0;
+  } else {
     vl = 0;
     hl = 0;
-	}
+  }
 
   if (shftl) shftl->shifted (*this);
 
-	return 1;
+  return 1;
 
 }
 
 int levels::rshift () { 
-	float vl = values[last];
-	int hl = heights[last];
+  float vl = values[last];
+  int hl = heights[last];
 
   int wrap = cbwrap.state;
-	if (wrap == 0) {
-		if (hl) return 0;
-	}
+  if (wrap == 0) {
+    if (hl) return 0;
+  }
 
-	for (int j = last, i = last - 1; j > 0; --j, --i) {
-		values[j]=values[i];
-		heights[j]=heights[i];
-	}
+  for (int j = last, i = last - 1; j > 0; --j, --i) {
+    values[j]=values[i];
+    heights[j]=heights[i];
+  }
 
   float& v0 = values[0];
   int& h0 = heights[0];
 
-	if (wrap) {
-		v0 = vl;
-		h0 = hl;
-	} else {
-		v0 = 0;
+  if (wrap) {
+    v0 = vl;
+    h0 = hl;
+  } else {
+    v0 = 0;
     h0 = 0;
-	}
+  }
 
   if (shftl) shftl->shifted (*this);
 
-	return 1;
+  return 1;
 
 }
 
 void levels::selall () {
   nsel = 0;
-	for (int i = 0; i < n; ++i) {
-		if (heights[i]) {
+  for (int i = 0; i < n; ++i) {
+    if (heights[i]) {
       selection[i] = 1;
       ++nsel;
     }
-	}
-	clearbookmarks ();
+  }
+  clearbookmarks ();
 }
 
 void levels::selnon () {
-	for (int i = 0; i < n; ++i) selection[i] = 0;
-	nsel = 0;
-	clearbookmarks ();
+  for (int i = 0; i < n; ++i) selection[i] = 0;
+  nsel = 0;
+  clearbookmarks ();
 }
 
 void levels::invsel () {
-	for (int i = 0; i < n; ++i) {
-		bool& si = selection[i];
-		if (si) {
-			si = 0; 
-			--nsel;
-		}
-		else if (heights[i]) {
-			si = 1;
-			++nsel;
-		}
-	}
-	clearbookmarks ();
+  for (int i = 0; i < n; ++i) {
+    bool& si = selection[i];
+    if (si) {
+      si = 0; 
+      --nsel;
+    }
+    else if (heights[i]) {
+      si = 1;
+      ++nsel;
+    }
+  }
+  clearbookmarks ();
 }
 
 CLICKED_BUTTON (levels, alllis) {
@@ -512,83 +528,83 @@ void levels::set_pos (int x, int y) {
 
 void levels::addbookmark () {
 
-	if (nsel) {
-		bookmark* bm = new bookmark ();
-		int bs = bmk.size ();
-		if (bs) {
-			int lb = bs - 1;
-			bookmark* plb = bmk [lb];
-			bm->set_pos (minus.extents.left, plb->extents.bottom - state_button::SIZE2);
-		} else {
-			bm->set_pos (minus.extents.left, minus.extents.bottom - state_button::SIZE2);
-		}
+  if (nsel) {
+    bookmark* bm = new bookmark ();
+    int bs = bmk.size ();
+    if (bs) {
+      int lb = bs - 1;
+      bookmark* plb = bmk [lb];
+      bm->set_pos (minus.extents.left, plb->extents.bottom - state_button::SIZE2);
+    } else {
+      bm->set_pos (minus.extents.left, minus.extents.bottom - state_button::SIZE2);
+    }
 
-		for (int i = 0; i < n; ++i) if (selection[i]) bm->ids.push_back (i);
+    for (int i = 0; i < n; ++i) if (selection[i]) bm->ids.push_back (i);
 
-		clearbookmarks ();
+    clearbookmarks ();
 
-		bm->set_state (1, 0);
-		bm->set_listener (&bml);
-			
-		bmk.push_back (bm);
+    bm->set_state (1, 0);
+    bm->set_listener (&bml);
+      
+    bmk.push_back (bm);
     this->add_child (bm);
 
     cons << GREEN << "Bookmarked " << nsel << spc << name << eol;
 
-	} else {
-		cons << RED << "No " << name << " selected to bookmark. SHIFT+click " << name << " to select." << eol;
-	}
+  } else {
+    cons << RED << "No " << name << " selected to bookmark. SHIFT+click " << name << " to select." << eol;
+  }
 
 }
 
 void levels::removebookmark () {
-	for (vector<bookmark*>::iterator i = bmk.begin (), j = bmk.end (); i != j; ) {
-		bookmark* b = *i;
-		if (b->state) {
-			i = bmk.erase (i);
-			j = bmk.end ();
+  for (vector<bookmark*>::iterator i = bmk.begin (), j = bmk.end (); i != j; ) {
+    bookmark* b = *i;
+    if (b->state) {
+      i = bmk.erase (i);
+      j = bmk.end ();
       this->remove_child (b);
       delete b;
-		} else {
-			++i;
-		}
-	}
+    } else {
+      ++i;
+    }
+  }
 }
 
 void levels::removeallbookmarks () {
-	for (int i = 0, j = bmk.size (); i < j; ++i) {
-		bookmark* pbi = bmk[i];
-		this->remove_child (pbi);
+  for (int i = 0, j = bmk.size (); i < j; ++i) {
+    bookmark* pbi = bmk[i];
+    this->remove_child (pbi);
     delete pbi;
-	}
-	bmk.clear ();
+  }
+  bmk.clear ();
 }
 
 void levels::clearbookmarks () {
-	for (int i = 0, j = bmk.size (); i < j; ++i) bmk[i]->set_state (0,0);
+  for (int i = 0, j = bmk.size (); i < j; ++i) bmk[i]->set_state (0,0);
 }
 
 CLICKED_CHECKBUTTON (levels, bmlis) {
-	bookmark& b = dynamic_cast<bookmark&>(cb);
-	int s = b.state;
+  bookmark& b = dynamic_cast<bookmark&>(cb);
+  int s = b.state;
   levels& l = *( (levels*) data);
-	if (SHIFT)
-		; 
-	else {
-		l.selnon ();
-		if (s == 0) s = 1;
-		b.set_state (s, 0);
-	}
+  if (SHIFT)
+    ; 
+  else {
+    l.selnon ();
+    if (s == 0) s = 1;
+    b.set_state (s, 0);
+  }
 
   int sl [] = {-1, 1};
-	for (int i = 0, j = l.bmk.size (); i < j; ++i) {
-		if (&b == l.bmk[i]) {
-			vector<int>& ids = b.ids;
-			int n = ids.size ();
-			for (int m = 0; m < n; ++m) l.selection[ids[m]] = s;
-			l.nsel += (n * sl[s]);
-		}
-	}
+  for (int i = 0, j = l.bmk.size (); i < j; ++i) {
+    if (&b == l.bmk[i]) {
+      vector<int>& ids = b.ids;
+      int n = ids.size ();
+      for (int m = 0; m < n; ++m) l.selection[ids[m]] = s;
+      l.nsel += (n * sl[s]);
+    }
+  }
 }
 
 CLICKED_BUTTON (levels, minuslis) {
@@ -599,15 +615,10 @@ CLICKED_BUTTON (levels, crosslis) {
   ((levels*) data)->removeallbookmarks ();
 }
 
-/*MOVED (levels,szrlis) {
-  levels* pl = (levels *) data;
-  l->sized ();
-}*/
-
 void levels::moved () {
-	if (extents.top > szr.extents.bottom) {
-		height = extents.height = extents.top - szr.extents.bottom;
-		set_pos (posx, szr.posy);
-		reheight ();
-	}
+  if (extents.top > szr.extents.bottom) {
+    height = extents.height = extents.top - szr.extents.bottom;
+    set_pos (posx, szr.posy);
+    reheight ();
+  }
 }
