@@ -1,12 +1,12 @@
 /*
 * listeners.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
 
 
-#include "din.h"
+#include "microtonal-keyboard.h"
 #include "listeners.h"
 #include "beat2value.h"
 #include "delay.h"
@@ -15,37 +15,34 @@
 #include "fft.h"
 #include "ui_list.h"
 #include "main.h"
-
-extern fft fft0;
-extern din din0;
-extern keyboard_keyboard keybd2;
-extern mondrian mondrian0;
-
+#include "subdiv.h"
 
 void curve_listener::edited (curve_editor* ed, int i) {
   ed->render_curve_samples ();
-	curve_info& ci = ed->curveinfo[i];
-	multi_curve* crv = ci.curve;
-	ed->hlabel_only = crv->shapeform;
-	if (ed->mix.num_vertices) ed->mix.clear ();
+  curve_info& ci = ed->curveinfo[i];
+  multi_curve* crv = ci.curve;
+  ed->hlabel_only = crv->shapeform;
+  if (ci.mix.num_vertices) ci.mix.clear ();
 }
 
 void wave_listener::edited (curve_editor* ed, int i) {
+  curve_info& ci = ed->curveinfo [i];
+  multi_curve& mix = ci.mix;
   switch (which) {
     case MICROTONAL_KEYBOARD:
-      din0.wavsol.update ();
-			if (ed->mix.num_vertices) din0.wavplay.set_mix (ed->mix);
+      mkb.wavsol.update ();
+      if (mix.num_vertices) mkb.wavplay.set_mix (mix, "microtonal-keyboard-waveform");
       break;
     case KEYBOARD_KEYBOARD:
-      keybd2.update_waveform (ed->mix);
+      keybd2.update_waveform (mix);
       break;
     case DRONE:
-      din0.update_drone_solvers (ed->mix);
+      mkb.update_drone_solvers (mix);
       break;
     case MONDRIAN:
-      mondrian0.update_waveform (ed->mix);
+      mondrian0.update_waveform (mix);
   }
-  if (fft0.folded () == 0) fft0.go (ed->curveinfo[i].curve);
+  uis.dofft ();
   curve_listener::edited (ed, i);
 }
 
@@ -53,13 +50,18 @@ beat2value_listener::beat2value_listener () : bv (0) {}
 
 void beat2value_listener::edited (curve_editor* ed, int i) {
   bv->sol.update ();
-	if (ed->mix.num_vertices) bv->set_mix (ed->mix);
+  curve_info& ci = ed->curveinfo [i];
+  multi_curve& mix = ci.mix;
+  if (mix.num_vertices) bv->set_mix (mix, "beat2value");
   curve_listener::edited (ed, i);
+  subdiv_.dirty = 1;
 }
 
 void drone_mod_lis::edited (curve_editor* ed, int i) {
-	din0.update_drone_mod_solvers (i, ed->mix);
-	curve_listener::edited (ed, i);
+  curve_info& ci = ed->curveinfo [i];
+  multi_curve& mix = ci.mix;
+  mkb.update_drone_mod_solvers (i, mix);
+  curve_listener::edited (ed, i);
 }
 
 void morse_code_listener::edited (curve_editor* ed, int i) {}
