@@ -1,6 +1,6 @@
 /*
 * noiser.cc
-* DIN Is Noise is copyright (c) 2006-2024 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -11,22 +11,21 @@
 #include "console.h"
 
 noiser::noiser () {
-	warp (&interp);
-	last_vol = 0.0f;
-	set_spread (0.0f);
-	set_value (0);
-  //setcur = setnext = 1;
+  warp (&interp);
+  last_vol = 0.0f;
+  set_spread (0.0f);
+  set_value (0);
 }
 
 void noiser::set_value (float v) {
   value.cur = v;
-	value.next = random_value ();
-	value.delta = value.next - value.cur;
-	alpha.val = 0.0f;
+  value.next = random_value ();
+  value.delta = value.next - value.cur;
+  alpha.val = 0.0f;
 }
 
 void noiser::calc_delta_alpha () {
-	if (samples.due < 3) alpha.delta = 1; else alpha.delta = 1.0f / (samples.due - 1);
+  if (samples.due < 3) alpha.delta = 1; else alpha.delta = 1.0f / (samples.due - 1);
 }
 
 void noiser::set_samples (float sn) {
@@ -37,31 +36,33 @@ void noiser::set_samples (float sn) {
 }
 
 void noiser::set_spread (float s) {
-	spread = s;
-	random_value.set (-spread, spread);
+  spread = s;
+  random_value.set (-spread, spread);
 }
 
 void noiser::operator() (float* L, float* R, int n, float* vola) {
-	for (int i = 0; i < n; ++i) { 
-		alpha.val += alpha.delta; 
-		alpha.warp = warp (alpha.val); 
-		float no = value.cur + alpha.warp * value.delta; 
-		float vno = vola[i] * no;
-		L[i] += vno;
-		R[i] += vno;
-		if (++samples.cur < samples.due); else {
-			set_value (no);
-			samples.cur = 0;
-			samples.err += samples.derr;
-			if (samples.err < 1.0f) {
-				samples.due = samples.duei;
-			} else {
-				samples.due = samples.duei + 1;
-				samples.err = 1.0f - samples.err;
-			}
-			calc_delta_alpha ();
-		}
-	}
+  for (int i = 0; i < n; ++i) { 
+    alpha.val += alpha.delta; 
+    alpha.warp = warp (alpha.val); 
+    float no = value.cur + alpha.warp * value.delta; 
+    float vno = vola[i] * no;
+    L[i] += vno;
+    R[i] += vno;
+    if (++samples.cur < samples.due)
+      ; 
+    else {
+      set_value (no);
+      samples.cur = 0;
+      samples.err += samples.derr;
+      if (samples.err < 1.0f) {
+        samples.due = samples.duei;
+      } else {
+        samples.due = samples.duei + 1;
+        samples.err = 1.0f - samples.err;
+      }
+      calc_delta_alpha ();
+    }
+  }
 }
 
 void noiser::operator() (float* L, float* R, int n, float vol) {
@@ -81,31 +82,31 @@ void noiser::operator() (float* L, float* R, int n, float vol) {
     setnext = 0;
     nextoff = 0;
   }*/
-	float v = last_vol;
-	float dv = (vol - last_vol) * 1.0f / n; 
-	for (int i = 0; i < n; ++i) { 
-		alpha.val += alpha.delta; 
-		alpha.warp = warp (alpha.val); 
-		float no = value.cur + alpha.warp * value.delta; 
-		v += dv;
-		float vno = v * no;
-		/*L[i] *= alpha.warp; //no; //alpha.warp;
+  float v = last_vol;
+  float dv = (vol - last_vol) * 1.0f / n; 
+  for (int i = 0; i < n; ++i) { 
+    alpha.val += alpha.delta; 
+    alpha.warp = warp (alpha.val); 
+    float no = value.cur + alpha.warp * value.delta; 
+    v += dv;
+    float vno = v * no;
+    /*L[i] *= alpha.warp; //no; //alpha.warp;
     R[i] = L[i];*/
 
     L[i] += vno;
     R[i] = L[i];
 
-		if (++samples.cur < samples.due); else {
+    if (++samples.cur < samples.due); else {
       set_value (no);
-			samples.cur = 0;
-			samples.err += samples.derr;
-			if (samples.err < 1.0f) {
-				samples.due = samples.duei;
-			} else {
-				samples.due = samples.duei + 1;
-				samples.err = 1.0f - samples.err;
+      samples.cur = 0;
+      samples.err += samples.derr;
+      if (samples.err < 1.0f) {
+        samples.due = samples.duei;
+      } else {
+        samples.due = samples.duei + 1;
+        samples.err = 1.0f - samples.err;
         calc_delta_alpha ();
-			}
+      }
       /*int nex = i + samples.due;
       if (nex >= n) {
         nextoff = nex - n;
@@ -117,13 +118,13 @@ void noiser::operator() (float* L, float* R, int n, float vol) {
       }
       value.delta = value.next - value.cur;*/
       alpha.val = 0.0f;
-		}
-	}
-	last_vol = vol;
+    }
+  }
+  last_vol = vol;
 }
 
 ofstream& operator<< (ofstream& o, noiser& n) {
-	extern const char spc;
-	o << n.spread << spc << n.samples.next;
-	return o;
+  extern const char spc;
+  o << n.spread << spc << n.samples.next;
+  return o;
 }
