@@ -1,6 +1,6 @@
 /*
 * phrasor.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -9,30 +9,29 @@
 #include "phrasor.h"
 #include "dingl.h"
 
-void phrasor::draw () {
+void phrasor::draw (box<int>& win) {
   int i;
-  float r, g, b;
   if (size) {
     if (state == phrasor::recording) {
       i = 0; 
-      r = 1; g = b = 0;
     } else {
       i = cur;
-      r = b = 0;
-      g = 1;
     }
-    glColor3f (r, g, b); 
-    draw_marker (data[i].x, data[i].y);
+    draw_marker (data[i].x, data[i].y, win);
   }
 }
 
-void phrasor::draw_marker (int x, int y) {
-	const int msize = 24;
+void phrasor::draw_marker (int x, int y, box<int>& win) {
   int mk [8];
-  mk[0]=x-msize;mk[1]=y;
-  mk[2]=x+msize;mk[3]=y;
-  mk[4]=x;mk[5]=y-msize;
-  mk[6]=x;mk[7]=y+msize;
+  mk[0]=win.left; 
+  mk[1]=y;
+  mk[2]=win.right; 
+  mk[3]=y;
+  mk[4]=x;
+  mk[5]=win.top;
+  mk[6]=x;
+  mk[7]=win.bottom;
+  glColor3f (0.7f, 0.7f, 0.3f);
   glVertexPointer (2, GL_INT, 0, mk);
   glDrawArrays (GL_LINES, 0, 4);
 }
@@ -54,16 +53,10 @@ int phrasor::validate () {
   return 1;
 }
 
-void phrasor::play () {
-  if (cur < size) state = playing;
-}
 
 void phrasor::set_cur (float amt) {
-  if (last != -1) {
+  if (size) {
     amount = amt;
     cur = amount * last;
   }
 }
-
-
-
