@@ -1,6 +1,6 @@
 /*
 * phrasor.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -27,9 +27,7 @@ struct phrasor {
 
   int cur;
 
-  phrasor () {
-    clear ();
-  }
+  phrasor () { clear (); }
 
   void add (point<int>& p) {
     data.push_back (p);
@@ -46,23 +44,29 @@ struct phrasor {
     data.clear ();
     cur = 0;
     size = 0; 
-    last = -1; 
-    last_1 = 0;
+    last = 0; 
+    last_1 = -1;
     amount = 0;
   }
 
-  void play ();
+  void rec () {
+    state = recording;
+    cur = 0;
+  }
 
-  void draw ();
-  void draw_marker (int x, int y);
+  void play () {
+    if (cur < size) state = playing;
+  }
+
+  void draw (box<int>& win);
+  void draw_marker (int x, int y, box<int>& win);
 
   int validate ();
   int next ();
   void set_cur (float amt);
 
+  int isrecording () { return state == recording;}
+
 };
 
 #endif
-
-
-
