@@ -1,6 +1,6 @@
 /*
 * scale_notes.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * For more information, please visit http://dinisnoise.org/
 */
 
@@ -23,13 +23,9 @@ struct scale_notes : widget, state_listener {
 
   label lbl;
 
-	static const int MAX_INTERVALS = 16; // non-general :( 
-	checkbutton cb_notes [MAX_INTERVALS];
+  static const int MAX_INTERVALS = 16; // non-general :( 
+  checkbutton cb_notes [MAX_INTERVALS];
   
-	scale_notes () {
-		lbl.set_moveable (1);
-	}
-
   void set_pos (int x, int y);
   int handle_input ();
   void draw ();
@@ -37,15 +33,10 @@ struct scale_notes : widget, state_listener {
   void update ();
   void refresh ();
 
-  template <typename T> void set_color (T r, T g, T b) {
-    lbl.set_color (r, g, b);
-  }
+  template <typename T> void set_color (T r, T g, T b) { lbl.set_color (r, g, b); }
 
   void changed (checkbutton& cb);
 
 };
 
 #endif
-
-
-
