@@ -1,6 +1,6 @@
 /*
 * sine_mixer.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -23,7 +23,6 @@ extern const float PI;
 extern const float TWO_PI;
 extern curve_library sin_lib;
 extern int line_height;
-extern const char SPC;
 
 sine_mixer::sine_mixer () : cp_sin ("sine_mixer_sin.crv"), sin_ed ("sine_mixer_sin.ed"), harms ("harmonics"), phase ("phases") {
   plugin::name = "Sine_Mixer";
@@ -44,24 +43,27 @@ sine_mixer::sine_mixer () : cp_sin ("sine_mixer_sin.crv"), sin_ed ("sine_mixer_s
   static const float fac = 0.6;
   phase.set_color (1.0f - fac * harms.clr.r, 1.0f - fac * harms.clr.g, 1.0f - fac * harms.clr.b);
   paintphase = 0;
+
+  titlemoving = 0;
+
 }
 
 void sine_mixer::load_params () {
   ifstream f (make_fname().c_str(), ios::in);
   string ignore;
   f >> ignore >> num_points >> ignore >> make_shapeform >> ignore >> type >> ignore >> auto_apply;
-	NUM_SINE_SAMPLES = num_points + 1;
+  NUM_SINE_SAMPLES = num_points + 1;
 }
 
 void sine_mixer::save_params () {
   ofstream f (make_fname().c_str(), ios::out);
-	string ignore;
-	f << "num_points " << int (sp_points.f_value) << " make_shapeform " << cb_make_shapeform.state << " type " << type \
+  string ignore;
+  f << "num_points " << sp_points.value << " make_shapeform " << cb_make_shapeform.state << " type " << type \
   << " auto_apply " << cb_auto_apply.state << endl;
 }
 
 sine_mixer::~sine_mixer () {
-	save_params ();
+  save_params ();
   widget_save ("d_sine_mixer", ctrls);
   dlog << "--- destroyed sine mixer ---" << endl;
 }
@@ -73,88 +75,88 @@ void sine_mixer::num_harmonics (int h) {
 }
 
 void sine_mixer::prep_harmonics () {
-	harmonics.resize (nharmonics);
-	float df = TWO_PI / (NUM_SINE_SAMPLES - 1);
+  harmonics.resize (nharmonics);
+  float df = TWO_PI / (NUM_SINE_SAMPLES - 1);
   funktion& f_sin = *pf_sin;
   for (int i = 0, j = 1; i < nharmonics; ++i, ++j) {
     vector< point<float> >& harmonic = harmonics[i];
-		harmonic.resize (NUM_SINE_SAMPLES);
+    harmonic.resize (NUM_SINE_SAMPLES);
     float dx = j * df; 
     float x = phase.values[i] * TWO_PI;
     for (int p = 0; p < NUM_SINE_SAMPLES; ++p) {
-			point<float>& hp = harmonic[p];
-			hp.x = cos(x);
-			hp.y = f_sin (x, TWO_PI);
+      point<float>& hp = harmonic[p];
+      hp.x = cos(x);
+      hp.y = f_sin (x, TWO_PI);
       x += dx;
       if (x > TWO_PI) x -= TWO_PI;
     }
   }
-	norm.resize (NUM_SINE_SAMPLES);
+  norm.resize (NUM_SINE_SAMPLES);
   mix ();
 }
 
 void sine_mixer::mix () {
-	for (int p = 0; p < NUM_SINE_SAMPLES; ++p) { point<float>& pi = norm[p]; pi.x = pi.y = 0;}
-	ss.str(""); ss << plugin::name;
+  for (int p = 0; p < NUM_SINE_SAMPLES; ++p) { point<float>& pi = norm[p]; pi.x = pi.y = 0;}
+  ss.str(""); ss << plugin::name;
   for (int i = 0; i < nharmonics; ++i) {
     float lev = harms.values[i];
     if (lev > 0) {
       vector< point<float> >& harmonic = harmonics[i];
       for (int p = 0; p < NUM_SINE_SAMPLES; ++p) {
-				point<float>& np = norm[p];
-				point<float>& hp = harmonic[p];
-				np.x += (lev * hp.x);
-				np.y += (lev * hp.y);
-    	}
-			ss << '_' << (i+1);
-  	}
-	}
+        point<float>& np = norm[p];
+        point<float>& hp = harmonic[p];
+        np.x += (lev * hp.x);
+        np.y += (lev * hp.y);
+      }
+      ss << '_' << (i+1);
+    }
+  }
   normalise ();
 }
 
 void sine_mixer::normalise () {
-	int n = NUM_SINE_SAMPLES;
+  int n = NUM_SINE_SAMPLES;
   if (n) {
-		point<float>& np0 = norm[0];
-		float maxy = fabs (np0.y), maxx = fabs (np0.x);
+    point<float>& np0 = norm[0];
+    float maxy = fabs (np0.y), maxx = fabs (np0.x);
     for (int i = 0; i < n; ++i) {
-			point<float>& pi = norm[i];
-			float vx = fabs (pi.x), vy = fabs (pi.y);
-			if (vx > maxx) maxx = vx;
-			if (vy > maxy) maxy = vy;
+      point<float>& pi = norm[i];
+      float vx = fabs (pi.x), vy = fabs (pi.y);
+      if (vx > maxx) maxx = vx;
+      if (vy > maxy) maxy = vy;
     }
     if (maxx != 0) for (int p = 0; p < n; ++p) norm[p].x /= maxx;
-		if (maxy != 0) for (int p = 0; p < n; ++p) norm[p].y /= maxy;
+    if (maxy != 0) for (int p = 0; p < n; ++p) norm[p].y /= maxy;
   }
 }
 
 void sine_mixer::render () {
 
-	undo = !cb_auto_apply.state;
-	shapeform = cb_make_shapeform.state;
+  undo = !cb_auto_apply.state;
+  shapeform = cb_make_shapeform.state;
 
-	int ns = norm.size ();
-	points.resize (ns);
-	if (shapeform) {
-  	for (int i = 0; i < ns; ++i) {
-    	point<float>& ni = norm[i];
-			point<float>& pi = points[i];
-			pi.x = ni.x;
-			pi.y = ni.y;
-  	}
-	} else {
-		float x = 0;
-		float dx = 1.0f / (NUM_SINE_SAMPLES - 1);
-  	for (int i = 0; i < ns; ++i) {
-    	point<float>& ni = norm[i];
-			point<float>& pi = points[i];
-			pi.x = x;
-			pi.y = ni.y;
-			x += dx;
-  	}
-	}
+  int ns = norm.size ();
+  points.resize (ns);
+  if (shapeform) {
+    for (int i = 0; i < ns; ++i) {
+      point<float>& ni = norm[i];
+      point<float>& pi = points[i];
+      pi.x = 0.5f + ni.x; // shapeforms centered at 0.5, 0
+      pi.y = ni.y;
+    }
+  } else {
+    float x = 0;
+    float dx = 1.0f / (NUM_SINE_SAMPLES - 1);
+    for (int i = 0; i < ns; ++i) {
+      point<float>& ni = norm[i];
+      point<float>& pi = points[i];
+      pi.x = x;
+      pi.y = ni.y;
+      x += dx;
+    }
+  }
 
-	gen_pts ();
+  gen_pts ();
 
 }
 
@@ -171,20 +173,20 @@ void sine_mixer::setup () {
     &olpaint,
   };
 
-	num_ctrls = 8;
+  num_ctrls = 8;
 
-	ctrls.resize (num_ctrls);
+  ctrls.resize (num_ctrls);
   for (int i = 0, j = 2; j < num_ctrls; ++i, ++j) ctrls[j] = _ctrls[i];
 
   load_params ();
 
-	sp_points.set ("Points", 1, 1, MILLION, this, 0);
-	sp_points.set_value (num_points);
+  sp_points.set ("Points", 1, 0, MILLION, this, 0);
+  sp_points.set_value (num_points);
 
-	cb_make_shapeform.set_text ("Make shapeform");
-	cb_make_shapeform.set_state (make_shapeform);
-	cb_make_shapeform.set_listener (this);
-	cbpaint.set_text ("Paint");
+  cb_make_shapeform.set_text ("Make shapeform");
+  cb_make_shapeform.set_state (make_shapeform);
+  cb_make_shapeform.set_listener (this);
+  cbpaint.set_text ("Paint");
 
   levs[0] = &harms;
   levs[1] = &phase;
@@ -192,10 +194,10 @@ void sine_mixer::setup () {
   pail.data = this;
   LISTEN (olpaint, &pail)
 
-	if (auto_apply) {
-		cb_auto_apply.set_state (1, 0);
-		plugin::mix = undo = 0;
-	}
+  if (auto_apply) {
+    cb_auto_apply.set_state (1, 0);
+    plugin::mix = undo = 0;
+  }
 
   ol_sin.set_listener (this);
 
@@ -232,25 +234,27 @@ void sine_mixer::set_type () {
 }
 
 void sine_mixer::changed (field& f) { 
-	if (&f == &sp_points.f_value) {
-		set_samples (f);
-		do_render ();
-	}
+  if (&f == &sp_points.f_value) {
+    int v = sp_points.value;
+    set_samples (v);
+    f = v;
+    do_render ();
+  }
 }
 
 void sine_mixer::changed (levels& l) {
   if (&l == &phase) prep_harmonics ();
-	mix ();
-	do_render ();
+  mix ();
+  do_render ();
 }
 
 void sine_mixer::changed (checkbutton& cb) {
-	if (&cb == &cb_make_shapeform) {
-		render ();
-		apply_not_auto_apply ();
-	} else if (&cb == &cbpaint) {
+  if (&cb == &cb_make_shapeform) {
+    render ();
+    apply_not_auto_apply ();
+  } else if (&cb == &cbpaint) {
     levs[paintphase]->paint = cbpaint.state;
-	} else plugin::changed (cb);
+  } else plugin::changed (cb);
 }
 
 void sine_mixer::set_samples (int s) {
@@ -260,11 +264,11 @@ void sine_mixer::set_samples (int s) {
 }
 
 void sine_mixer::apply_not_auto_apply () {
-	if (cb_auto_apply.state) {
-		plugin::mix = undo = 1;
-		uis.crved->apply_plugin (this);
-		plugin::mix = undo = 0;
-	} else uis.crved->apply_plugin (this);
+  if (cb_auto_apply.state) {
+    plugin::mix = undo = 1;
+    uis.crved->apply_plugin (this);
+    plugin::mix = undo = 0;
+  } else uis.crved->apply_plugin (this);
 }
 
 void sine_mixer::picked (label& lbl, int dir) {
@@ -275,13 +279,13 @@ void sine_mixer::picked (label& lbl, int dir) {
 }
 
 void sine_mixer::shift_apply () {
-	mix ();
-	render ();
-	apply_not_auto_apply ();
+  mix ();
+  render ();
+  apply_not_auto_apply ();
 }
 
 void sine_mixer::clicked (button& b) {
-	if (&b == &b_edit) uis.set_current (&sin_ed); 
+  if (&b == &b_edit) uis.set_current (&sin_ed); 
   else plugin::clicked (b);
 }
 
@@ -294,8 +298,8 @@ void sine_mixer::edited (curve_editor* e, int i) {
 
 
 void sine_mixer::moused (int dx, double scl) {
-	if (dx > 0) harms.rshift (); else harms.lshift ();
-	shift_apply ();
+  if (dx > 0) harms.rshift (); else harms.lshift ();
+  shift_apply ();
 }
 
 void sine_mixer::paint (levels& l) {
@@ -330,17 +334,16 @@ void sine_mixer::toggpaint (label& l) {
 
 }
 
-int sine_mixer::handle_input () {
+/*int sine_mixer::handle_input () {
   int r = plugin::handle_input ();
-  if (!_folded) {
+  if (folded == 0) {
     if (keypressed (SDLK_g)) {
-      pressed.g = 1;
       toggpaint (olpaint.option);
       r |= 1;
     }
   }
   return r;
-}
+}*/
 
 PICKED_OPTION (sine_mixer, paintlis) {
   sine_mixer& sm = (* (sine_mixer*) data);
@@ -356,3 +359,21 @@ MOVED (sine_mixer, szrmov) {
   plb->szr.setpos2 (pla->szr);
   plb->moved ();
 }
+
+MOVESTART (sine_mixer, szrmov) {
+  if (uis.plugin__browser.l_title.movr.move) {
+    sine_mixer* sm = (sine_mixer*) data;
+    sm->titlemoving = 1;
+    sm->harms.szr.movlis = 0;
+    sm->phase.szr.movlis = 0;
+  }
+}
+
+MOVEEND (sine_mixer, szrmov) {
+  sine_mixer* sm = (sine_mixer*) data;
+  if (sm->titlemoving) {
+    sm->titlemoving = 0;
+    sm->harms.szr.movlis = &sm->szm;
+    sm->phase.szr.movlis = &sm->szm;
+  }
+}
