@@ -1,6 +1,6 @@
 /*
 * textboard.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * For more information, please visit http://dinisnoise.org/
 */
 
@@ -13,31 +13,32 @@
 
 #include "ui.h"
 
-struct text {
+struct text { // for textboard
 
-  std::string txt; // actual text
-
-  // hline - label on horizontal line, vline = label on vertical line
-  enum {hline=0, vline=1, normal};
-  int type; 
-
-  enum {permanent, temporary};
-  int state;
+  std::string txt; 
 
   float r, g, b; // color
 
-  float wx, wy; // window co-ords
-  int vx, vy; // view co-ords
+  enum {forever, session, once}; 
+  int state;
 
+  // hline - label on horizontal line, vline = label on vertical line
+  enum {hline=0, vline=1, floating};
+  int type; 
+
+
+  int vx, vy; // view co-ords
+  float wx, wy; // window co-ords
+  
   text (
         const std::string& t, 
         float xx = 0, float yy = 0, 
         float rr=0.25, float gg=0.25, float bb=0.25, 
-        int s = text::temporary, int y = text::normal, 
+        int s = text::once, int y = text::floating, 
         float vxx = 0, float vyy = 0) : 
-        txt(t), type (y) , state (s), r(rr), g(gg), b(bb), wx(xx), wy(yy), vx(vxx), vy(vyy) {}
+        txt(t), r(rr), g(gg), b(bb), state(s), type (y), vx(vxx), vy(vyy), wx(xx), wy(yy) {}
 
-	bool operator== (const text& t) {return txt == t.txt;}
+  bool operator== (const text& t) {return txt == t.txt;}
 
 };
 
@@ -45,15 +46,22 @@ struct basic_editor;
 struct mondrian;
 
 struct textboard {
+
   std::list<text> texts;
+  void add (const text& t) { texts.push_back (t);}
+  void delallguides (int type);
+  void delnearestguide (int type, int vx, int vy);
+  void clear ();
+
   void draw (int shapeform = 0);
   void draw_line (int x1, int y1, int x2, int y2);
-  void add (const text& t) { texts.push_back (t);}
-  void clear ();
+
   void refresh (basic_editor* b, float dwx = 0, float dwy = 0, float dvx = 0, float dvy = 0);
   void refresh (mondrian* m);
+
   void load (std::ifstream& file);
   void save (std::ofstream& file);
+
 };
 
 #endif
