@@ -1,6 +1,6 @@
 /*
 * tokenizer.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -11,65 +11,51 @@
 
 #include "tokenizer.h"
 #include <cstdlib>
-
 #include <iostream>
 using namespace std;
 
 tokenizer::tokenizer() {
   str ("");
-  del (DEFAULT_DELIMITER);
 }
 
-tokenizer::tokenizer(const std::string& s, const std::string& d) {
+tokenizer::tokenizer(const std::string& s) {
   str (s);
-  del (d);
 }
 
 tokenizer::tokenizer (const std::vector<std::string>& t) {
   vec (t);
 }
 
-void tokenizer::set (const std::string& s, const std::string& d) {
-  str (s);
-  del (d);
-}
-
 void tokenizer::str (const std::string& s) {
-  buffer = s;
-  blen = buffer.length ();
-  init_cur ();
-  tokens_available = 0;
-}
-
-void tokenizer::del (const std::string& d) {
-  delimiter = d;
-  dlen = delimiter.length ();
+  buf = s;
+  len = buf.length ();
+  cur = 0;
+  avail = 0;
 }
 
 void tokenizer::vec (const std::vector<std::string>& t) {
   tokens = t;
-  tokens_available = 1;
-  tokid = 0;
-}
-
-void tokenizer::init_cur () {
-  if (blen) cur = 0; else cur = -1;
+  ntok = tokens.size ();
+  avail = 1;
+  id = 0;
 }
 
 tokenizer& tokenizer::operator>> (std::string& s) {
-  if (tokens_available) {
-    if (tokid < tokens.size()) s = tokens[tokid++]; else {
+  if (avail) {
+    if (id < ntok) 
+      s = tokens [id++]; 
+    else {
       s = "";
-      cur = blen;
+      cur = len;
     }
   } else {
     token = "";
-    if (blen < 1) {
+    if (len < 1) {
       s = token;
     } else {
-      skip_ws ();
-      while ((cur < blen) && !isdelim (buffer[cur])) {
-        token += buffer[cur];
+      skipws ();
+      while (cur < len && (buf[cur] != delim)) {
+        token += buf[cur];
         ++cur;
       }
       s = token;
@@ -108,26 +94,22 @@ tokenizer& tokenizer::operator>> (unsigned char& c) {
   return *this;
 }
 
-void tokenizer::skip_ws () {
-  while (cur < blen) if (!isdelim (buffer[cur])) break; else ++cur;
-}
-
-bool tokenizer::isdelim (char c) {
-  for (int i = 0; i < dlen; ++i) {
-    if (delimiter[i] == c) return true;
-  }
-  return false;
+void tokenizer::skipws () {
+  while (cur < len) 
+    if (buf[cur] == delim)  
+      ++cur; 
+    else 
+      break;
 }
 
 string tokenizer::cur2end () {
-  if (tokens_available) {
+  if (avail) {
     string result;
-    static const char spc = ' ';
-    for (int i = tokid, j = tokens.size(); i < j; ++i) result = result + tokens[i] + spc;
+    for (int i = id, j = tokens.size(); i < j; ++i) result += (tokens[i] + spc);
     return result;
   } else {
-    if (cur > -1) {
-      return buffer.substr (cur, blen - 1);
-    } else return "";
+    if (cur > -1) 
+      return buf.substr (cur, len - 1);
   }
+  return "";
 }
