@@ -1,6 +1,6 @@
 /*
 * tokenizer.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * For more information, please visit http://dinisnoise.org/
 */
 
@@ -14,12 +14,12 @@
 #include <string>
 #include <vector>
 
+extern const char spc;
+
 struct tokenizer {
 
-	static const std::string DEFAULT_DELIMITER;
-
   tokenizer();
-  tokenizer(const std::string& s, const std::string& d=DEFAULT_DELIMITER);
+  tokenizer(const std::string& s);
   tokenizer (const std::vector<std::string>& tokens);
 
   tokenizer& operator>> (std::string& s);
@@ -30,25 +30,21 @@ struct tokenizer {
   tokenizer& operator>> (unsigned char& c);
 
   std::vector<std::string> tokens;
-  int tokens_available;
-  unsigned int tokid;
+  int avail;
+  int ntok;
+  int id;
 
-  std::string delimiter;
-  std::string buffer;
-  int blen, dlen;
+  std::string buf;
+  int len;
   void str (const std::string& s);
-  void del (const std::string& d);
   void vec (const std::vector<std::string>& v);
-  void set (const std::string& s, const std::string& d=DEFAULT_DELIMITER);
-  bool isdelim (char c);
 
-  void skip_ws ();
+  static char delim;
+  void skipws ();
 
   int cur;
-  void init_cur ();
 
   std::string cur2end ();
-
   std::string token;
 
 };
