@@ -1,6 +1,6 @@
 /*
 * ui.h
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * For more information, please visit http://dinisnoise.org/
 */
 
@@ -11,12 +11,15 @@
 #include <string>
 
 struct ui { // or screen
-	std::string name; 
-	int ed; // editor?
-  int inst; // instrument?
-	int prev_mousex, prev_mousey; // mouse in device space co-ords
 
-  static ui* over;
+  std::string name; 
+
+  int ed; // editor?
+  int inst; // instrument?
+
+  int prev_mousex, prev_mousey; // in device space
+
+  static ui* over; // for overlay
 
   virtual void enter ();
   virtual void leave ();
@@ -25,12 +28,12 @@ struct ui { // or screen
   virtual void draw() {}
   virtual void drawerlay () { if (over) over->draw (); }
   virtual void bg () {}
-	virtual int esc () {return 0;}
+  virtual int esc () {return 0;}
+
   ui () { prev_mousex = prev_mousey = -1; ed = 0; inst = 0;} 
+
   virtual ~ui () {}
 
 };
+
 #endif
-
-
-
