@@ -1,6 +1,6 @@
 /*
 * viewwin.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2026 Jagannathan Sampath
 * For more information, please visit https://dinisnoise.org/
 */
 
@@ -9,44 +9,41 @@
 #include "viewwin.h"
 #include "main.h"
 #include "log.h"
-
+#include "console.h"
 #include <iostream>
+
 using namespace std;
 
 viewport::viewport () {
   width = height = 0;
-	width_change = height_change = -1;
   xmax = ymax = 0;
   xmax_1 = ymax_1 = 0;
 }
 
 viewport::~viewport () {
-	dlog << "--- destroyed viewport: " << width << " x " << height << " ---" << endl;
+  dlog << "--- destroyed viewport: " << width << spc << height << " ---" << endl;
 }
 
 void viewport::operator() (int w, int h) {
-  if (w != width || h != height) {
-    calc (w, h);
-  }
+  if (w != width || h != height) calc (w, h);
 }
 
 void viewport::calc (int w, int h) {
-	if (width != 0) width_change = w * 1.0f / width; else width_change = -1;
-	if (height != 0) height_change = h * 1.0f / height; else height_change = -1;
   width = w;
   height = h;
   xmax = width - 1;
   ymax = height - 1;
   xmax_1 = 1.0f / xmax;
   ymax_1 = 1.0f / ymax;
-	midx = width / 2;
-	midy = height / 2;
+  midx = width / 2;
+  midy = height / 2;
   handle_factor = handle_radius * 1.0f / width;
+  dlog << "*** viewport changed to : " << w << spc << h << " ***" << endl;
 }
 
 bool viewport::inside (int x, int y) {
-  bool xi = (x >= 0) && (x <= xmax);
-  bool yi = (y >= 0) && (y <= ymax);
+  int xi = (x > -1) && (x < width);
+  int yi = (y > -1) && (y < height);
   return (xi && yi);
 }
 
@@ -129,9 +126,9 @@ void window::update_mouse () {
 }
 
 int window::diff_mouse (float& dx, float& dy) {
-	dx = mousex - mousex_prev;
-	dy = mousey - mousey_prev;
-	if (dx || dy) return 1; else return 0;
+  dx = mousex - mousex_prev;
+  dy = mousey - mousey_prev;
+  if (dx || dy) return 1; else return 0;
 }
 
 void window::calc_viewwin () {
